@@ -1,20 +1,7 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 from rez.packages import iter_packages
 from rez.exceptions import BuildProcessError, BuildContextResolveError, \
     ReleaseHookCancellingError, RezError, ReleaseError, BuildError, \
@@ -25,9 +12,9 @@ from rez.resolved_context import ResolvedContext
 from rez.release_hook import create_release_hooks
 from rez.resolver import ResolverStatus
 from rez.config import config
-from rez.vendor.enum import Enum
 from contextlib import contextmanager
-from pipes import quote
+from enum import Enum
+from shlex import quote
 import getpass
 import os.path
 import sys
@@ -45,7 +32,13 @@ def get_build_process_types():
 def create_build_process(process_type, working_dir, build_system, package=None,
                          vcs=None, ensure_latest=True, skip_repo_errors=False,
                          ignore_existing_tag=False, verbose=False, quiet=False):
-    """Create a `BuildProcess` instance."""
+    """Create a :class:`BuildProcess` instance.
+
+    .. warning::
+
+       The working_dir argument and the pacakge keyword argument will are deprecated
+       and will be removed in rez 3.0.0
+    """
     from rez.plugin_managers import plugin_manager
     process_types = get_build_process_types()
     if process_type not in process_types:
@@ -90,9 +83,9 @@ class BuildProcess(object):
         """Create a BuildProcess.
 
         Args:
-            working_dir (DEPRECATED): Ignored.
+            working_dir (DEPRECATED): Will be removed in rez 3.0.0.
             build_system (`BuildSystem`): Build system used to build the package.
-            package (DEPRECATED): Ignored.
+            package (DEPRECATED): Will be removed in rez 3.0.0.
             vcs (`ReleaseVCS`): Version control system to use for the release
                 process.
             ensure_latest: If True, do not allow the release process to occur
