@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
@@ -66,7 +55,7 @@ def check_production_install():
         sys.stderr.write(
             "Pip-based rez installation detected. Please be aware that rez command "
             "line tools are not guaranteed to function correctly in this case. See "
-            "https://github.com/nerdvegas/rez/wiki/Installation#why-not-pip-for-production "
+            "https://rez.readthedocs.io/en/stable/installation.html#why-not-pip-for-production "
             " for futher details.\n"
         )
 
@@ -283,8 +272,7 @@ def run_rez_benchmark():
     check_production_install()
 
     # Special case - we have to override config settings here, before rez is
-    # loaded. TODO this would be cleaner if we had an Application object, see
-    # https://github.com/nerdvegas/rez/issues/1043
+    # loaded. TODO this would be cleaner if we had an Application object, see #1043
     #
     # /start
     import json
