@@ -1,23 +1,10 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 The main command-line entry point.
 """
-from __future__ import print_function
-
 import sys
 import importlib
 from argparse import _StoreTrueAction, SUPPRESS
@@ -100,7 +87,7 @@ def setup_parser():
         LazyArgumentParser: Argument parser for rez command.
     """
     py = sys.version_info
-    parser = LazyArgumentParser("rez")
+    parser = LazyArgumentParser("rez", description="rez CLI")
 
     parser.add_argument("-i", "--info", action=InfoAction,
                         help="print information about rez and exit")
