@@ -1,20 +1,7 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 import os
 import sys
 import signal
@@ -70,7 +57,9 @@ subcommands = {
     },
     "status": {},
     "suite": {},
-    "test": {},
+    "test": {
+        "arg_mode": "grouped"
+    },
     "view": {},
     "yaml2py": {},
     "bundle": {},
@@ -121,7 +110,7 @@ def load_plugin_cmd():
         except Exception:
             if config.debug("plugins"):
                 import traceback
-                from rez.vendor.six.six import StringIO
+                from io import StringIO
                 out = StringIO()
                 traceback.print_exc(file=out)
                 print_debug(out.getvalue())
@@ -185,12 +174,16 @@ class LazyArgumentParser(ArgumentParser):
 
     def format_help(self):
         """Sets up all sub-parsers when help is requested."""
+        self._setup_all_subparsers()
+        return super(LazyArgumentParser, self).format_help()
+
+    def _setup_all_subparsers(self):
+        """Sets up all sub-parsers on demand."""
         if self._subparsers:
             for action in self._subparsers._actions:
                 if isinstance(action, LazySubParsersAction):
                     for parser_name, parser in action._name_parser_map.items():
                         action._setup_subparser(parser_name, parser)
-        return super(LazyArgumentParser, self).format_help()
 
 
 _handled_int = False
