@@ -1,23 +1,10 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 '''
 Build a package from source.
 '''
-from __future__ import print_function
-
 import os
 
 
@@ -43,11 +30,13 @@ def setup_parser_common(parser):
     """Parser setup common to both rez-build and rez-release."""
     from rez.build_process import get_build_process_types
     from rez.build_system import get_valid_build_systems
+    from rez.config import config
     from rez.exceptions import PackageMetadataError
 
     process_types = get_build_process_types()
     parser.add_argument(
-        "--process", type=str, choices=process_types, default="local",
+        "--process", type=str, choices=process_types,
+        default=config.default_build_process,
         help="the build process to use (default: %(default)s).")
 
     # add build system choices valid for this package
