@@ -1,28 +1,13 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """See util.create_forwarding_script()."""
 import argparse
-from rez.vendor.six import six
 
 __doc__ = argparse.SUPPRESS
 
 
-basestring = six.string_types[0]
-
-
 def setup_parser(parser, completions=False):
     parser.add_argument("YAML", type=str)
     parser.add_argument("ARG", type=str, nargs=argparse.REMAINDER)
@@ -34,7 +19,7 @@ def command(opts, parser, extra_arg_groups=None):
     from rez.exceptions import RezSystemError
     from rez.vendor import yaml
     from rez.vendor.yaml.error import YAMLError
-    from rez.utils import py23
+    from rez.util import get_function_arg_names
     import os.path
 
     # we don't usually want warnings printed in a wrapped tool. But in cases
@@ -66,9 +51,9 @@ def command(opts, parser, extra_arg_groups=None):
     nargs = doc.get("nargs", [])
     kwargs = doc.get("kwargs", {})
 
-    if isinstance(doc["module"], basestring):
+    if isinstance(doc["module"], str):
         # refers to a rez module
-        from rez.backport.importlib import import_module
+        from importlib import import_module
         namespace = "rez.%s" % doc["module"]
         module = import_module(namespace)
     else:
@@ -78,7 +63,7 @@ def command(opts, parser, extra_arg_groups=None):
         module = plugin_manager.get_plugin_module(plugin_type, plugin_name)
 
     target_func = getattr(module, func_name)
-    func_args = py23.get_function_arg_names(target_func)
+    func_args = get_function_arg_names(target_func)
 
     if "_script" in func_args:
         kwargs["_script"] = yaml_file
