@@ -1,22 +1,10 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 Install a pip-compatible python package, and its dependencies, as rez packages.
 """
-from __future__ import print_function
 from argparse import REMAINDER
 import logging
 
@@ -27,10 +15,6 @@ def setup_parser(parser, completions=False):
         help="python version (rez package) to use, default is latest. Note "
         "that the pip package(s) will be installed with a dependency on "
         "python-MAJOR.MINOR.")
-    parser.add_argument(
-        "--pip-version", dest="pip_ver", metavar="VERSION",
-        help="pip version (rez package) to use, default is latest."
-        " This option is deprecated and will be removed in the future.")
     parser.add_argument(
         "-i", "--install", action="store_true",
         help="install the package")
@@ -60,24 +44,13 @@ def command(opts, parser, extra_arg_groups=None):
         logging.getLogger('rez').setLevel(logging.INFO)
 
     from rez.pip import pip_install_package
-    import warnings
 
     # a bit weird, but there used to be more options. Leave like this for now
     if not opts.install:
         parser.error("Expected one of: --install")
 
-    if opts.pip_ver:
-        with warnings.catch_warnings():
-            # Cause all warnings to always be triggered.
-            warnings.simplefilter("always")
-            warnings.warn(
-                "The option --pip-version is deprecated and will be removed in a future version",
-                category=DeprecationWarning
-            )
-
     pip_install_package(
         opts.PACKAGE,
-        pip_version=opts.pip_ver,
         python_version=opts.py_ver,
         release=opts.release,
         prefix=opts.prefix,
