@@ -1,22 +1,10 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 '''
 Manipulate a package cache.
 '''
-from __future__ import print_function
 from argparse import SUPPRESS
 import os.path
 import sys
@@ -53,6 +41,14 @@ def setup_parser(parser, completions=False):
     group.add_argument(
         "--daemon", action="store_true", help=SUPPRESS
     )
+    parser.add_argument(
+        "--pkg-cache-mode",
+        choices=["sync", "async"],
+        default=None,
+        help="If provided, override the rezconfig's package_cache_async key. "
+             "If 'sync', the process will block until packages are cached. "
+             "If 'async', the process will not block while packages are cached."
+    )
     parser.add_argument(
         "-c", "--columns", nargs='+', choices=column_choices,
         default=["status", "package", "variant_uri", "cache_path"],
@@ -61,7 +57,7 @@ def setup_parser(parser, completions=False):
     parser.add_argument(
         "-f", "--force", action="store_true",
         help="Force a package add, even if package is not cachable. Only "
-        "applicable with --add"
+        "applicable with --add-variants"
     )
     parser.add_argument(
         "DIR", nargs='?',
@@ -71,6 +67,9 @@ def setup_parser(parser, completions=False):
 
 
 def add_variant(pkgcache, uri, opts):
+    import shutil
+
+    from rez.config import config
     from rez.packages import get_variant_from_uri
     from rez.utils.logging_ import print_info, print_warning
     from rez.package_cache import PackageCache
@@ -82,12 +81,30 @@ def add_variant(pkgcache, uri, opts):
         print("No such variant: %s" % uri, file=sys.stderr)
         sys.exit(1)
 
-    destpath, status = pkgcache.add_variant(variant, force=opts.force)
+    if opts.pkg_cache_mode == "async":
+        sync = False
+    elif opts.pkg_cache_mode == "sync":
+        sync = True
+    else:
+        sync = not config.package_cache_async
+
+    destpath, status = pkgcache.add_variant(
+        variant, force=opts.force,
+        wait_for_copying=sync
+    )
 
     if status == PackageCache.VARIANT_FOUND:
         print_info("Already exists: %s", destpath)
     elif status == PackageCache.VARIANT_COPYING:
         print_warning("Another process is currently copying to: %s", destpath)
+    elif status == PackageCache.VARIANT_SKIPPED:
+        free = shutil.disk_usage(config.cache_packages_path).free / 1024**2
+        buffer = config.package_cache_space_buffer / 1024**2
+        print_warning(
+            "Cache no longer accepting new variant due to size limit.\n"
+            f"Remaining cache free space: {free:.2f}MB is near "
+            f"configured buffer {buffer:.2f}MB (config.package_cache_space_buffer)."
+        )
     else:
         print_info("Successfully cached to: %s", destpath)
 
