@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 from rez.config import config
@@ -22,15 +11,18 @@ class Command(object):
     To register plugin and expose subcommand, the plugin module..
 
     * MUST have a module-level docstring (used as the command help)
-    * MUST provide a `setup_parser()` function
-    * MUST provide a `command()` function
-    * MUST provide a `register_plugin()` function
-    * SHOULD have a module-level attribute `command_behavior`
+    * MUST provide a ``setup_parser()`` function
+    * MUST provide a ``command()`` function
+    * MUST provide a ``register_plugin()`` function
+    * SHOULD have a module-level attribute ``command_behavior``
 
-    For example, a plugin named 'foo' and this is the `foo.py`:
+    For example, a plugin named 'foo' and this is the ``foo.py``:
 
-        '''The docstring for command help, this is required.
-        '''
+    .. code-block:: python
+
+        \"""
+        The docstring for command help, this is required.
+        \"""
         from rez.command import Command
 
         command_behavior = {
