@@ -1,19 +1,7 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
-from __future__ import absolute_import
 from rez import __version__
 from rez.utils.data_utils import AttrDictWrapper, RO_AttrDictWrapper, \
     convert_dicts, cached_property, cached_class_property, LazyAttributeMeta, \
@@ -26,17 +14,34 @@ from rez import module_root_path
 from rez.system import system
 from rez.vendor.schema.schema import Schema, SchemaError, And, Or, Use
 from rez.vendor import yaml
-from rez.vendor.six import six
 from rez.vendor.yaml.error import YAMLError
-from rez.backport.lru_cache import lru_cache
+import rez.deprecations
 from contextlib import contextmanager
+from functools import lru_cache
 from inspect import ismodule
 import os
 import re
 import copy
 
 
-basestring = six.string_types[0]
+class _Deprecation(object):
+    def __init__(self, removed_in, extra=None):
+        self.__removed_in = removed_in
+        self.__extra = extra or ""
+
+    def get_message(self, name, env_var=False):
+        if self.__removed_in:
+            return (
+                "config setting named {0!r} {1}is "
+                "deprecated and will be removed in {2}. {3}"
+            ).format(
+                name,
+                "(configured through the {0} environment variable) ".format(env_var)
+                if env_var
+                else "",
+                self.__removed_in,
+                self.__extra
+            ).strip()
 
 
 # -----------------------------------------------------------------------------
@@ -46,7 +51,7 @@ basestring = six.string_types[0]
 class Setting(object):
     """Setting subclasses implement lazy setting validators.
 
-    Note that lazy setting validation only happens on master configuration
+    Note that lazy setting validation only happens on main configuration
     settings - plugin settings are validated on load only.
     """
     schema = Schema(object)
@@ -83,13 +88,31 @@ class Setting(object):
             # next, env-var
             value = os.getenv(self._env_var_name)
             if value is not None:
+                if self.key in _deprecated_settings:
+                    rez.deprecations.warn(
+                        _deprecated_settings[self.key].get_message(
+                            self.key, env_var=self._env_var_name
+                        ),
+                        rez.deprecations.RezDeprecationWarning,
+                        pre_formatted=True,
+                        filename=self._env_var_name,
+                    )
                 return self._parse_env_var(value)
 
             # next, JSON-encoded env-var
             varname = self._env_var_name + "_JSON"
             value = os.getenv(varname)
             if value is not None:
-                from rez.utils import json
+                if self.key in _deprecated_settings:
+                    rez.deprecations.warn(
+                        _deprecated_settings[self.key].get_message(
+                            self.key, env_var=varname
+                        ),
+                        rez.deprecations.RezDeprecationWarning,
+                        pre_formatted=True,
+                        filename=varname,
+                    )
+                import json
 
                 try:
                     return json.loads(value)
@@ -112,25 +135,25 @@ class Setting(object):
 
 
 class Str(Setting):
-    schema = Schema(basestring)
+    schema = Schema(str)
 
     def _parse_env_var(self, value):
         return value
 
 
 class Char(Setting):
-    schema = Schema(basestring, lambda x: len(x) == 1)
+    schema = Schema(str, lambda x: len(x) == 1)
 
     def _parse_env_var(self, value):
         return value
 
 
 class OptionalStr(Str):
-    schema = Or(None, basestring)
+    schema = Or(None, str)
 
 
 class StrList(Setting):
-    schema = Schema([basestring])
+    schema = Schema([str])
     sep = ','
 
     def _parse_env_var(self, value):
@@ -162,7 +185,7 @@ class PipInstallRemaps(Setting):
 
 class OptionalStrList(StrList):
     schema = Or(And(None, Use(lambda x: [])),
-                [basestring])
+                [str])
 
 
 class PathList(StrList):
@@ -300,7 +323,7 @@ class ExecutableScriptMode_(Str):
 
 
 class OptionalStrOrFunction(Setting):
-    schema = Or(None, basestring, callable)
+    schema = Or(None, str, callable)
 
     def _parse_env_var(self, value):
         # note: env-var override only supports string, eg 'mymodule.preprocess_func'
@@ -355,6 +378,7 @@ config_schema = Schema({
     "resetting_variables":                          StrList,
     "release_hooks":                                StrList,
     "context_tracking_context_fields":              StrList,
+    "pathed_env_vars":                              StrList,
     "prompt_release_message":                       Bool,
     "critical_styles":                              OptionalStrList,
     "error_styles":                                 OptionalStrList,
@@ -373,6 +397,7 @@ config_schema = Schema({
     "release_packages_path":                        Str,
     "dot_image_format":                             Str,
     "build_directory":                              Str,
+    "default_build_process":                        Str,
     "documentation_url":                            Str,
     "suite_visibility":                             SuiteVisibility_,
     "rez_tools_visibility":                         RezToolsVisibility_,
@@ -410,6 +435,7 @@ config_schema = Schema({
     "alias_back":                                   OptionalStr,
     "package_preprocess_function":                  OptionalStrOrFunction,
     "package_preprocess_mode":                      PreprocessMode_,
+    "error_on_missing_variant_requires":            Bool,
     "context_tracking_host":                        OptionalStr,
     "variant_shortlinks_dirname":                   OptionalStr,
     "build_thread_count":                           BuildThreadCount_,
@@ -423,12 +449,14 @@ config_schema = Schema({
     "shell_error_truncate_cap":                     Int,
     "package_cache_log_days":                       Int,
     "package_cache_max_variant_days":               Int,
+    "package_cache_space_buffer":                   Int,
+    "package_cache_used_threshold":                 Int,
     "package_cache_clean_limit":                    Float,
     "allow_unversioned_packages":                   Bool,
-    "rxt_as_yaml":                                  Bool,
     "package_cache_during_build":                   Bool,
     "package_cache_local":                          Bool,
     "package_cache_same_device":                    Bool,
+    "package_cache_async":                          Bool,
     "color_enabled":                                ForceOrBool,
     "resolve_caching":                              Bool,
     "cache_package_files":                          Bool,
@@ -459,13 +487,12 @@ config_schema = Schema({
     "default_relocatable":                          Bool,
     "set_prompt":                                   Bool,
     "prefix_prompt":                                Bool,
+    # Note that if you want to remove a warn_* or debug_* config, you will
+    # need to search for "config.warn(" or "config.debug(" to see if it's used.
     "warn_old_commands":                            Bool,
     "error_old_commands":                           Bool,
     "debug_old_commands":                           Bool,
-    "warn_commands2":                               Bool,
-    "error_commands2":                              Bool,
     "rez_1_environment_variables":                  Bool,
-    "rez_1_cmake_variables":                        Bool,
     "disable_rez_1_compatibility":                  Bool,
     "make_package_temporarily_writable":            Bool,
     "read_package_cache":                           Bool,
@@ -486,11 +513,21 @@ config_schema = Schema({
 })
 
 
+# List of settings that are deprecated and should raise
+# deprecation warnings if referenced in config files.
+_deprecated_settings = {
+    "warn_old_commands": _Deprecation("the future"),
+    "error_old_commands": _Deprecation("the future"),
+    "rez_1_environment_variables": _Deprecation("the future"),
+    "disable_rez_1_compatibility": _Deprecation("the future")
+}
+
+
 # settings common to each plugin type
 _plugin_config_dict = {
     "release_vcs": {
-        "tag_name":                     basestring,
-        "releasable_branches":          Or(None, [basestring]),
+        "tag_name":                     str,
+        "releasable_branches":          Or(None, [str]),
         "check_tag":                    bool
     }
 }
@@ -500,15 +537,15 @@ _plugin_config_dict = {
 # Config
 # -----------------------------------------------------------------------------
 
-class Config(six.with_metaclass(LazyAttributeMeta, object)):
+class Config(object, metaclass=LazyAttributeMeta):
     """Rez configuration settings.
 
     You should call the `create_config` function, rather than constructing a
     `Config` object directly.
 
     Config files are merged with other config files to create a `Config`
-    instance. The 'rezconfig' file in rez acts as the master - other config
-    files update the master configuration to create the final config. See the
+    instance. The 'rezconfig' file in rez acts as the primary - other config
+    files update the primary configuration to create the final config. See the
     comments at the top of 'rezconfig' for more details.
     """
     schema = config_schema
@@ -656,7 +693,7 @@ class Config(six.with_metaclass(LazyAttributeMeta, object)):
             return []
         else:
             keys = (
-                [x for x in self._schema_keys if isinstance(x, basestring)]
+                [x for x in self._schema_keys if isinstance(x, str)]
                 + ["plugins"]
             )
             keys = [x for x in keys if x.startswith(prefix)]
@@ -730,7 +767,7 @@ class Config(six.with_metaclass(LazyAttributeMeta, object)):
         return Config(filepaths, overrides)
 
     def __str__(self):
-        keys = (x for x in self.schema._schema if isinstance(x, basestring))
+        keys = (x for x in self.schema._schema if isinstance(x, str))
         return "%r" % sorted(list(keys) + ["plugins"])
 
     def __repr__(self):
@@ -856,7 +893,7 @@ class _PluginConfigs(object):
 def expand_system_vars(data):
     """Expands any strings within `data` such as '{system.user}'."""
     def _expanded(value):
-        if isinstance(value, basestring):
+        if isinstance(value, str):
             value = expandvars(value)
             value = expanduser(value)
             return scoped_format(value, system=system)
@@ -960,6 +997,7 @@ def _load_config_from_filepaths(filepaths):
     loaders = ((".py", _load_config_py),
                ("", _load_config_yaml))
 
+    root_config = get_module_root_config()
     for filepath in filepaths:
         for extension, loader in loaders:
             if extension:
@@ -972,6 +1010,20 @@ def _load_config_from_filepaths(filepaths):
                 continue
 
             data_ = loader(filepath_with_ext)
+
+            if filepath != root_config:
+                for key in data_:
+                    if key in _deprecated_settings:
+                        rez.deprecations.warn(
+                            _deprecated_settings[key].get_message(
+                                key,
+                                env_var=False,
+                            ),
+                            rez.deprecations.RezDeprecationWarning,
+                            pre_formatted=True,
+                            filename=filepath_with_ext,
+                        )
+
             deep_update(data, data_)
             sourced_filepaths.append(filepath_with_ext)
             break
@@ -985,3 +1037,9 @@ def get_module_root_config():
 
 # singleton
 config = Config._create_main_config()
+
+if os.getenv("REZ_LOG_DEPRECATION_WARNINGS"):
+    # If REZ_LOG_DEPRECATION_WARNINGS is set, force all configs
+    # to be loaded so that we can raise warnings appropriately with all
+    # the commands, etc.
+    config.data
