@@ -2,6 +2,7 @@
 # Copyright Contributors to the Rez Project
 
 
+import json
 import os
 import os.path
 import errno
@@ -14,6 +15,7 @@ import sys
 import platform
 import time
 import logging
+import logging.config
 import random
 import threading
 from contextlib import contextmanager
@@ -21,13 +23,13 @@ from contextlib import contextmanager
 from rez.config import config
 from rez.exceptions import PackageCacheError
 from rez.vendor.lockfile import LockFile, NotLocked
-from rez.utils import json
-from rez.utils.filesystem import safe_listdir, safe_makedirs, safe_remove, \
-    forceful_rmtree
+from rez.vendor.progress.spinner import PixelSpinner
+from rez.utils.filesystem import forceful_rmtree, safe_listdir, safe_remove
 from rez.utils.colorize import ColorizedStreamHandler
 from rez.utils.logging_ import print_warning
 from rez.packages import get_variant
 from rez.system import system
+from rez.utils.filesystem import rename
 
 
 class PackageCache(object):
@@ -41,14 +43,13 @@ class PackageCache(object):
 
     * A rez-env is performed;
     * The context is resolved;
-    * For each variant in the context, we check to see if it's present in the
-      current package cache;
+    * For each variant in the context, we check to see if it's present in the current package cache;
     * If it is, the variant's root is remapped to this location.
 
-    A package cache is _not_ a package repository. It just stores copies of
+    A package cache is **not** a package repository. It just stores copies of
     variant payloads - no package definitions are stored.
 
-    Payloads are stored into the following structure:
+    Payloads are stored into the following structure::
 
         /<cache_dir>/foo/1.0.0/af8d/a/<payload>
                                    /a.json
@@ -62,13 +63,27 @@ class PackageCache(object):
     matching variant.
     """
 
-    VARIANT_NOT_FOUND = 0  # Variant was not found
-    VARIANT_FOUND = 1  # Variant was found
-    VARIANT_CREATED = 2  # Variant was created
-    VARIANT_COPYING = 3  # Variant payload is still being copied to this cache
-    VARIANT_COPY_STALLED = 4  # Variant payload copy has stalled
-    VARIANT_PENDING = 5  # Variant is pending caching
-    VARIANT_REMOVED = 6  # Variant was deleted
+    VARIANT_NOT_FOUND = 0  #: Variant was not found
+    VARIANT_FOUND = 1  #: Variant was found
+    VARIANT_CREATED = 2  #: Variant was created
+    VARIANT_COPYING = 3  #: Variant payload is still being copied to this cache
+    VARIANT_COPY_STALLED = 4  #: Variant payload copy has stalled
+    VARIANT_PENDING = 5  #: Variant is pending caching
+    VARIANT_REMOVED = 6  #: Variant was deleted
+    VARIANT_SKIPPED = 7  # Variant was not cached due to cache size limit
+
+    STATUS_DESCRIPTIONS = {
+        VARIANT_NOT_FOUND: "was not found",
+        VARIANT_FOUND: "was found",
+        VARIANT_CREATED: "was created",
+        VARIANT_COPYING: "payload is still being copied to this cache",
+        VARIANT_COPY_STALLED: "payload copy has stalled.\nSee "
+                              "https://rez.readthedocs.io/en/stable/caching.html#cleaning-the-cache "
+                              "for more information.",
+        VARIANT_PENDING: "is pending caching",
+        VARIANT_REMOVED: "was deleted",
+        VARIANT_SKIPPED: "is not being cached due to cache size limit"
+    }
 
     _FILELOCK_TIMEOUT = 10
     _COPYING_TIME_INC = 0.2
@@ -86,9 +101,9 @@ class PackageCache(object):
         self.path = path
 
         # make dirs for internal use
-        safe_makedirs(self._log_dir)
-        safe_makedirs(self._pending_dir)
-        safe_makedirs(self._remove_dir)
+        os.makedirs(self._log_dir, exist_ok=True)
+        os.makedirs(self._pending_dir, exist_ok=True)
+        os.makedirs(self._remove_dir, exist_ok=True)
 
     def get_cached_root(self, variant):
         """Get location of variant payload copy.
@@ -117,7 +132,81 @@ class PackageCache(object):
 
         return rootpath
 
-    def add_variant(self, variant, force=False):
+    def get_variant_size(self, free, variant_root):
+        """Get the size of the variant root.
+
+        Args:
+            free: The available free cache space.
+            variant_root: The rez resolved variant root.
+
+        Returns:
+            int: The size in bytes of the variant root (may exceed buffer slightly).
+        """
+        variant_size = 0
+        seen_inodes = set()
+        stack = [variant_root]
+
+        while stack:
+            current = stack.pop()
+            try:
+                with os.scandir(current) as ref:
+                    for entry in ref:
+                        try:
+                            # Since we are following symlinks, track visited inodes to make sure
+                            # we are not double counting files.
+                            st = entry.stat(follow_symlinks=True)
+                            inode = (st.st_dev, st.st_ino)
+                            if inode in seen_inodes:
+                                continue
+                            seen_inodes.add(inode)
+
+                            if stat.S_ISREG(st.st_mode):
+                                variant_size += st.st_size
+                                # Bail out early if variant size will overtake the buffer
+                                # set by config.package_cache_space_buffer.
+                                if (free - variant_size) < config.package_cache_space_buffer:
+                                    return variant_size
+                            elif stat.S_ISDIR(st.st_mode):
+                                stack.append(entry.path)
+                        except OSError:
+                            continue
+            except OSError:
+                continue
+
+        return variant_size
+
+    def cache_near_full(self):
+        """ Get the cache available space
+
+        Returns:
+            bool: True if available cache space is below buffer, otherwise False.
+        """
+        _, _, free = shutil.disk_usage(self.path)
+        return free < config.package_cache_space_buffer
+
+    def variant_meets_space_requirements(self, rez_variant_root):
+        """Check if the cache usage is above config.package_cache_used_threshold.
+        If it is, start throttling the cache by checking each variants size to make sure
+        it's not going to take the cache size below the minimum buffer we set.
+
+        Args:
+            variant_root: The rez resolved variant root.
+
+        Returns:
+            bool:
+                - True if the cache space used is below config.package_cache_used_threshold.
+                - False if (free - variant_size) < config.package_cache_space_buffer, otherwise False.
+        """
+        total, used, free = shutil.disk_usage(self.path)
+        used_percentage = (used / total) * 100 if total else 0.0
+
+        if used_percentage > config.package_cache_used_threshold:
+            variant_size = self.get_variant_size(free, rez_variant_root)
+            return (free - variant_size) > config.package_cache_space_buffer
+
+        return True
+
+    def add_variant(self, variant, force=False, wait_for_copying=False, logger=None):
         """Copy a variant's payload into the cache.
 
         The following steps are taken to ensure muti-thread/proc safety, and to
@@ -145,21 +234,19 @@ class PackageCache(object):
           config.package_cache_same_device' is False.
 
         Args:
-            variant (`Variant`): The variant to copy into this cache
+            variant (Variant): The variant to copy into this cache
             force (bool): Copy the variant regardless. Use at your own risk (there
                 is no guarantee the resulting variant payload will be functional).
+            wait_for_copying (bool): Whether the caching step should block when one of the
+                pending variants is marked as already copying.
+            logger (None | Logger): If a logger is provided, log information to it.
 
         Returns:
-            2-tuple:
+            tuple: 2-tuple:
             - str: Path to cached payload
-            - int: One of:
-              - VARIANT_FOUND
-              - VARIANT_CREATED
-              - VARIANT_COPYING
-              - VARIANT_COPY_STALLED
+            - int: One of VARIANT_FOUND, VARIANT_CREATED, VARIANT_COPYING, VARIANT_COPY_STALLED, VARIANT_SKIPPED
         """
         from rez.utils.base26 import get_next_base26
-        from rez.utils.filesystem import safe_makedirs
 
         # do some sanity checking on variant to cache
         package = variant.parent
@@ -190,16 +277,9 @@ class PackageCache(object):
                     "Not cached - package is local: %s" % package.uri
                 )
 
-            # Package is already on same disk device as package cache. Note that
-            # this check is skipped on Windows + Py<3.4, as os.stat does not
-            # support device identification.
-            #
-            dev_stat_not_supported = (
-                platform.system() == "Windows"
-                and sys.version_info[:2] < (3, 4)
-            )
+            # Package is already on same disk device as package cache
 
-            if not config.package_cache_same_device and not dev_stat_not_supported:
+            if not config.package_cache_same_device:
                 st_pkgcache = os.stat(self.path)
                 st_variant = os.stat(variant_root)
                 if st_pkgcache.st_dev == st_variant.st_dev:
@@ -210,7 +290,7 @@ class PackageCache(object):
 
             # Package belongs to a temp repo (this occurs when a package is
             # tested on pre_build/pre_release - see
-            # https://github.com/AcademySoftwareFoundation/rez/wiki/Package-Definition-Guide#tests)
+            # https://rez.readthedocs.io/en/stable/package_definition.html#tests)
             #
             if package.repository.name() == "filesystem" and \
                     package.repository.location.startswith(config.tmpdir + os.sep):
@@ -219,20 +299,50 @@ class PackageCache(object):
                     % package.repository
                 )
 
-        no_op_statuses = (
+        no_op_statuses = {
             self.VARIANT_FOUND,
-            self.VARIANT_COPYING,
-            self.VARIANT_COPY_STALLED
-        )
+            self.VARIANT_COPY_STALLED,
+        }
+        if not wait_for_copying:
+            # Copying variants are only no-ops if we want to ignore them.
+            no_op_statuses.add(self.VARIANT_COPYING)
 
         # variant already exists, or is being copied to cache by another thread/proc
         status, rootpath = self._get_cached_root(variant)
         if status in no_op_statuses:
+            if logger:
+                logger.warning(f"Not caching {variant.qualified_name}. "
+                               f"Variant {self.STATUS_DESCRIPTIONS[status]}")
             return (rootpath, status)
 
+        if wait_for_copying and status == self.VARIANT_COPYING:
+            spinner = PixelSpinner(f"Waiting for {variant.qualified_name} to finish copying. ")
+            while status == self.VARIANT_COPYING:
+                spinner.next()
+                time.sleep(self._COPYING_TIME_INC)
+                status, rootpath = self._get_cached_root(variant)
+
+            # Status has changed, so report the change and return
+            if logger:
+                if status == self.VARIANT_FOUND:
+                    # We have resolved into a satisfactory state
+                    logger.info(
+                        f"{variant.qualified_name} {self.STATUS_DESCRIPTIONS[status]}"
+                    )
+                else:
+                    logger.warning(
+                        f"{variant.qualified_name} {self.STATUS_DESCRIPTIONS[status]}"
+                    )
+            return (rootpath, status)
+
+        # Block adding new variant to cache from rez-pkg-cache --add-variants
+        # if the cache size is almost full.
+        if self.cache_near_full() or not self.variant_meets_space_requirements(variant_root):
+            return (rootpath, self.VARIANT_SKIPPED)
+
         # 1.
         path = self._get_hash_path(variant)
-        safe_makedirs(path)
+        os.makedirs(path, exist_ok=True)
 
         # construct data to store to json file
         data = {
@@ -342,7 +452,7 @@ class PackageCache(object):
                     os.chmod(rootpath, st.st_mode | stat.S_IWUSR)
 
                 # actually a mv
-                os.rename(rootpath, dest_rootpath)
+                rename(rootpath, dest_rootpath)
 
             except OSError as e:
                 if e.errno == errno.ENOENT:
@@ -376,20 +486,39 @@ class PackageCache(object):
 
         This method is called when a context is created or sourced. Variants
         are then added to the cache in a separate process.
+
+        .. deprecated:: 3.2.0
+           Use :method:`add_variants` instead.
+        """
+        return self.add_variants(variants, package_cache_async=True)
+
+    def add_variants(self, variants, package_cache_async=True):
+        """Add the given variants to the package payload cache.
         """
 
-        # A prod install is necessary because add_variants_async works by
+        # A prod install is necessary because add_variants works by
         # starting a rez-pkg-cache proc, and this can only be done reliably in
         # a prod install. On non-windows we could fork instead, but there would
         # remain no good solution on windows.
         #
         if not system.is_production_rez_install:
             raise PackageCacheError(
-                "PackageCache.add_variants_async is only supported in a "
+                "PackageCache.add_variants is only supported in a "
                 "production rez installation."
             )
 
         variants_ = []
+        cachable_statuses = {
+            self.VARIANT_NOT_FOUND,
+        }
+        if not package_cache_async:
+            # We want to monitor copying variants if we're synchronous.
+            # We also want to report that a status has been stalled, so we'll
+            # hand that off to the caching function as well
+            cachable_statuses.update({
+                self.VARIANT_COPYING,
+                self.VARIANT_COPY_STALLED,
+            })
 
         # trim down to those variants that are cachable, and not already cached
         for variant in variants:
@@ -397,7 +526,7 @@ class PackageCache(object):
                 continue
 
             status, _ = self._get_cached_root(variant)
-            if status == self.VARIANT_NOT_FOUND:
+            if status in cachable_statuses:
                 variants_.append(variant)
 
         # if there are no variants to add, and no potential cleanup to do, then exit
@@ -438,6 +567,20 @@ class PackageCache(object):
             with open(filepath, 'w') as f:
                 f.write(json.dumps(handle_dict))
 
+        if package_cache_async:
+            self._subprocess_package_caching_daemon(self.path)
+        else:
+            # syncronous caching
+            self._run_caching_operation(wait_for_copying=True)
+
+    @staticmethod
+    def _subprocess_package_caching_daemon(path):
+        """
+        Run the package cache in a daemon process
+
+        Returns:
+            subprocess.Popen : The package caching daemon process
+        """
         # configure executable
         if platform.system() == "Windows":
             kwargs = {
@@ -454,7 +597,7 @@ class PackageCache(object):
             raise RuntimeError("Did not find rez-pkg-cache executable")
 
         # start caching subproc
-        args = [exe, "--daemon", self.path]
+        args = [exe, "--daemon", path]
 
         try:
             with open(os.devnull, 'w') as devnull:
@@ -465,8 +608,8 @@ class PackageCache(object):
                 else:
                     out_target = devnull
 
-                subprocess.Popen(
-                    [exe, "--daemon", self.path],
+                return subprocess.Popen(
+                    args,
                     stdout=out_target,
                     stderr=out_target,
                     **kwargs
@@ -482,7 +625,8 @@ class PackageCache(object):
         """Get variants and their current statuses from the cache.
 
         Returns:
-            List of 3-tuple:
+            tuple: List of 3-tuple:
+
             - `Variant`: The cached variant
             - str: Local cache path for variant, if determined ('' otherwise)
             - int: Status. One of:
@@ -568,6 +712,15 @@ class PackageCache(object):
             if pid > 0:
                 sys.exit(0)
 
+        self._run_caching_operation(wait_for_copying=False)
+
+    def _run_caching_operation(self, wait_for_copying=True):
+        """Copy pending variants.
+
+        Args:
+            wait_for_copying (bool): Whether the caching step should block when one of the
+                pending variants is marked as already copying.
+        """
         logger = self._init_logging()
 
         # somewhere for the daemon to store stateful info
@@ -578,7 +731,7 @@ class PackageCache(object):
         # copy variants into cache
         try:
             while True:
-                keep_running = self._run_daemon_step(state)
+                keep_running = self._run_caching_step(state, wait_for_copying=wait_for_copying)
                 if not keep_running:
                     break
         except Exception:
@@ -598,8 +751,8 @@ class PackageCache(object):
         This should be run periodically via 'rez-pkg-cache --clean'.
 
         This removes:
-        - Variants that have not been used in more than
-          'config.package_cache_max_variant_days' days;
+
+        - Variants that have not been used in more than 'config.package_cache_max_variant_days' days;
         - Variants that have stalled;
         - Variants that are already pending deletion (remove_variant() was used).
 
@@ -692,12 +845,21 @@ class PackageCache(object):
             except NotLocked:
                 pass
 
-    def _run_daemon_step(self, state):
+    def _run_caching_step(self, state, wait_for_copying=False):
         logger = state["logger"]
 
+        # Keep the cache daemon alive until the cache size reaches its min threshold.
+        if self.cache_near_full():
+            logger.info(
+                "Cache storage has reached the configured threshold of "
+                f"{config.package_cache_space_buffer / 1024**2:.2f}MB, caching will now stop."
+            )
+            return False
+
         # pick a random pending variant to copy
         pending_filenames = set(os.listdir(self._pending_dir))
-        pending_filenames -= set(state.get("copying", set()))
+        if not wait_for_copying:
+            pending_filenames -= set(state.get("copying", set()))
         if not pending_filenames:
             return False
 
@@ -714,13 +876,24 @@ class PackageCache(object):
             raise
 
         variant = get_variant(variant_handle_dict)
+        variant_root = getattr(variant, "root")
+
+        if not self.variant_meets_space_requirements(variant_root):
+            # variant cannot be cached due to its size, so remove as a pending variant.
+            logger.info(f"Variant {variant_root} is too big to be cached due to remaining cache space.")
+            safe_remove(filepath)
+            return True
 
         # copy the variant and log activity
         logger.info("Started caching of variant %s...", variant.uri)
         t = time.time()
 
         try:
-            rootpath, status = self.add_variant(variant)
+            rootpath, status = self.add_variant(
+                variant,
+                wait_for_copying=wait_for_copying,
+                logger=logger,
+            )
 
         except PackageCacheError as e:
             # variant cannot be cached, so remove as a pending variant
@@ -768,6 +941,11 @@ class PackageCache(object):
           manually (hence the logging to stdout also)
         """
         logger = logging.getLogger("rez-pkg-cache")
+        logging_conf = os.getenv("REZ_LOGGING_CONF")
+        if logging_conf:
+            logging.config.fileConfig(logging_conf, disable_existing_loggers=False)
+            return logger
+
         logger.setLevel(logging.INFO)
         logger.propagate = False
 
