@@ -15,28 +15,24 @@ from rez.package_repository import create_memory_package_repository
 from rez.packages import Package
 from rez.package_py_utils import expand_requirement
 from rez.vendor.schema.schema import Schema, Optional, Or, Use, And
-from rez.vendor.six import six
-from rez.vendor.version.version import Version
+from rez.version import Version
 from contextlib import contextmanager
 import os
 
 
-basestring = six.string_types[0]
-
-
 # this schema will automatically harden request strings like 'python-*'; see
 # the 'expand_requires' function for more info.
 #
-package_request_schema = Or(And(basestring, Use(expand_requirement)),
+package_request_schema = Or(And(str, Use(expand_requirement)),
                             And(PackageRequest, Use(str)))
 
 tests_schema = Schema({
-    Optional(basestring): Or(
-        Or(basestring, [basestring]),
+    Optional(str): Or(
+        Or(str, [str]),
         extensible_schema_dict({
-            "command": Or(basestring, [basestring]),
+            "command": Or(str, [str]),
             Optional("requires"): [package_request_schema],
-            Optional("run_on"): Or(basestring, [basestring]),
+            Optional("run_on"): Or(str, [str]),
             Optional("on_variants"): Or(
                 bool,
                 {
@@ -50,14 +46,14 @@ tests_schema = Schema({
 
 
 package_schema = Schema({
-    Optional("requires_rez_version"):   And(basestring, Use(Version)),
+    Optional("requires_rez_version"):   And(str, Use(Version)),
 
-    Required("name"):                   basestring,
-    Optional("base"):                   basestring,
-    Optional("version"):                Or(basestring,
+    Required("name"):                   str,
+    Optional("base"):                   str,
+    Optional("version"):                Or(str,
                                            And(Version, Use(str))),
-    Optional('description'):            basestring,
-    Optional('authors'):                [basestring],
+    Optional('description'):            str,
+    Optional('authors'):                [str],
 
     Optional('requires'):               late_bound([package_request_schema]),
     Optional('build_requires'):         late_bound([package_request_schema]),
@@ -71,9 +67,9 @@ package_schema = Schema({
     Optional('relocatable'):            late_bound(Or(None, bool)),
     Optional('cachable'):               late_bound(Or(None, bool)),
 
-    Optional('uuid'):                   basestring,
+    Optional('uuid'):                   str,
     Optional('config'):                 dict,
-    Optional('tools'):                  late_bound([basestring]),
+    Optional('tools'):                  late_bound([str]),
     Optional('help'):                   late_bound(help_schema),
 
     Optional('tests'):                  late_bound(tests_schema),
@@ -85,12 +81,12 @@ package_schema = Schema({
     Optional('pre_test_commands'):      _commands_schema,
 
     # attributes specific to pre-built packages
-    Optional("build_system"):           basestring,
-    Optional("build_command"):          Or([basestring], basestring, False),
+    Optional("build_system"):           str,
+    Optional("build_command"):          Or([str], str, False),
     Optional("preprocess"):             _function_schema,
 
     # arbitrary fields
-    Optional(basestring):               object
+    Optional(str):               object
 })
 
 
@@ -175,9 +171,9 @@ def make_package(name, path, make_base=None, make_root=None, skip_existing=True,
     Args:
         name (str): Package name.
         path (str): Package repository path to install package into.
-        make_base (callable): Function that is used to create the package
+        make_base (typing.Callable): Function that is used to create the package
             payload, if applicable.
-        make_root (callable): Function that is used to create the package
+        make_root (typing.Callable): Function that is used to create the package
             variant payloads, if applicable.
         skip_existing (bool): If True, detect if a variant already exists, and
             skip with a warning message if so.
@@ -224,15 +220,13 @@ def make_package(name, path, make_base=None, make_root=None, skip_existing=True,
 
             base = variant_.base
             if make_base and base:
-                if not os.path.exists(base):
-                    os.makedirs(base)
+                os.makedirs(base, exist_ok=True)
                 os.chdir(base)
                 make_base(variant_, base)
 
             root = variant_.root
             if make_root and root:
-                if not os.path.exists(root):
-                    os.makedirs(root)
+                os.makedirs(root, exist_ok=True)
                 os.chdir(root)
                 make_root(variant_, root)
 
