@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 from rez.utils.resources import Resource
@@ -23,18 +12,14 @@ from rez.utils.filesystem import find_matching_symlink
 from rez.utils.formatting import PackageRequest
 from rez.exceptions import PackageMetadataError, ResourceError
 from rez.config import config, Config, create_config
-from rez.vendor.version.version import Version
+from rez.version import Version
 from rez.vendor.schema.schema import Schema, SchemaError, Optional, Or, And, Use
-from rez.vendor.six import six
 
 from textwrap import dedent
 import os.path
 from hashlib import sha1
 
 
-basestring = six.string_types[0]
-
-
 # package attributes created at release time
 package_release_keys = (
     "timestamp",
@@ -68,8 +53,8 @@ package_rex_keys = (
 # utility schemas
 # ------------------------------------------------------------------------------
 
-help_schema = Or(basestring,  # single help entry
-                 [[basestring]])  # multiple help entries
+help_schema = Or(str,  # single help entry
+                 [[str]])  # multiple help entries
 
 _is_late = And(SourceCode, lambda x: hasattr(x, "_late"))
 
@@ -80,7 +65,7 @@ def late_bound(schema):
 
 # used when 'requires' is late bound
 late_requires_schema = Schema([
-    Or(PackageRequest, And(basestring, Use(PackageRequest)))
+    Or(PackageRequest, And(str, Use(PackageRequest)))
 ])
 
 
@@ -92,7 +77,7 @@ late_requires_schema = Schema([
 #
 
 base_resource_schema_dict = {
-    Required("name"): basestring
+    Required("name"): str
 }
 
 
@@ -106,20 +91,20 @@ package_family_schema_dict = base_resource_schema_dict.copy()
 #
 
 tests_schema = Schema({
-    Optional(basestring): Or(
-        Or(basestring, [basestring]),
+    Optional(str): Or(
+        Or(str, [str]),
         extensible_schema_dict({
-            "command": Or(basestring, [basestring]),
+            "command": Or(str, [str]),
             Optional("requires"): [
-                Or(PackageRequest, And(basestring, Use(PackageRequest)))
+                Or(PackageRequest, And(str, Use(PackageRequest)))
             ],
-            Optional("run_on"): Or(basestring, [basestring]),
+            Optional("run_on"): Or(str, [str]),
             Optional("on_variants"): Or(
                 bool,
                 {
                     "type": "requires",
                     "value": [
-                        Or(PackageRequest, And(basestring, Use(PackageRequest)))
+                        Or(PackageRequest, And(str, Use(PackageRequest)))
                     ]
                 }
             )
@@ -130,10 +115,10 @@ tests_schema = Schema({
 package_base_schema_dict = base_resource_schema_dict.copy()
 package_base_schema_dict.update({
     # basics
-    Optional("base"):                   basestring,
+    Optional("base"):                   str,
     Optional("version"):                Version,
-    Optional('description'):            basestring,
-    Optional('authors'):                [basestring],
+    Optional('description'):            str,
+    Optional('authors'):                [str],
 
     # dependencies
     Optional('requires'):               late_bound([PackageRequest]),
@@ -142,12 +127,12 @@ package_base_schema_dict.update({
 
     # plugins
     Optional('has_plugins'):            late_bound(bool),
-    Optional('plugin_for'):             late_bound([basestring]),
+    Optional('plugin_for'):             late_bound([str]),
 
     # general
-    Optional('uuid'):                   basestring,
+    Optional('uuid'):                   str,
     Optional('config'):                 Config,
-    Optional('tools'):                  late_bound([basestring]),
+    Optional('tools'):                  late_bound([str]),
     Optional('help'):                   late_bound(help_schema),
 
     # build related
@@ -170,14 +155,14 @@ package_base_schema_dict.update({
     # release info
     Optional("timestamp"):              int,
     Optional('revision'):               object,
-    Optional('changelog'):              basestring,
-    Optional('release_message'):        Or(None, basestring),
+    Optional('changelog'):              str,
+    Optional('release_message'):        Or(None, str),
     Optional('previous_version'):       Version,
     Optional('previous_revision'):      object,
-    Optional('vcs'):                    basestring,
+    Optional('vcs'):                    str,
 
     # arbitrary fields
-    Optional(basestring):               late_bound(object)
+    Optional(str):               late_bound(object)
 })
 
 
@@ -212,23 +197,23 @@ variant_schema = Schema(variant_schema_dict)
 
 _commands_schema = Or(SourceCode,       # commands as converted function
                       callable,         # commands as function
-                      basestring,       # commands in text block
-                      [basestring])     # old-style (rez-1) commands
+                      str,       # commands in text block
+                      [str])     # old-style (rez-1) commands
 
 _function_schema = Or(SourceCode, callable)
 
-_package_request_schema = And(basestring, Use(PackageRequest))
+_package_request_schema = And(str, Use(PackageRequest))
 
 package_pod_schema_dict = base_resource_schema_dict.copy()
 
-large_string_dict = And(basestring, Use(lambda x: dedent(x).strip()))
+large_string_dict = And(str, Use(lambda x: dedent(x).strip()))
 
 
 package_pod_schema_dict.update({
-    Optional("base"):                   basestring,
-    Optional("version"):                And(basestring, Use(Version)),
+    Optional("base"):                   str,
+    Optional("version"):                And(str, Use(Version)),
     Optional('description'):            large_string_dict,
-    Optional('authors'):                [basestring],
+    Optional('authors'):                [str],
 
     Optional('requires'):               late_bound([_package_request_schema]),
     Optional('build_requires'):         late_bound([_package_request_schema]),
@@ -238,12 +223,12 @@ package_pod_schema_dict.update({
     Optional('variants'):               [[_package_request_schema]],
 
     Optional('has_plugins'):            late_bound(bool),
-    Optional('plugin_for'):             late_bound([basestring]),
+    Optional('plugin_for'):             late_bound([str]),
 
-    Optional('uuid'):                   basestring,
+    Optional('uuid'):                   str,
     Optional('config'):                 And(dict,
                                             Use(lambda x: create_config(overrides=x))),
-    Optional('tools'):                  late_bound([basestring]),
+    Optional('tools'):                  late_bound([str]),
     Optional('help'):                   late_bound(help_schema),
 
     Optional('hashed_variants'):        bool,
@@ -262,13 +247,13 @@ package_pod_schema_dict.update({
     Optional("timestamp"):              int,
     Optional('revision'):               object,
     Optional('changelog'):              large_string_dict,
-    Optional('release_message'):        Or(None, basestring),
-    Optional('previous_version'):       And(basestring, Use(Version)),
+    Optional('release_message'):        Or(None, str),
+    Optional('previous_version'):       And(str, Use(Version)),
     Optional('previous_revision'):      object,
-    Optional('vcs'):                    basestring,
+    Optional('vcs'):                    str,
 
     # arbitrary keys
-    Optional(basestring):               late_bound(object)
+    Optional(str):               late_bound(object)
 })
 
 
@@ -281,13 +266,9 @@ package_pod_schema = Schema(package_pod_schema_dict)
 
 class PackageRepositoryResource(Resource):
     """Base class for all package-related resources.
-
-    Attributes:
-        schema_error (`Exception`): Type of exception to throw on bad data.
-        repository_type (str): Type of package repository associated with this
-            resource type.
     """
     schema_error = PackageMetadataError
+    #: Type of package repository associated with this resource type.
     repository_type = None
 
     @classmethod
@@ -442,7 +423,7 @@ class PackageResourceHelper(PackageResource):
                 print_warning(msg)
             commands = convert_old_commands(commands)
 
-        if isinstance(commands, basestring):
+        if isinstance(commands, str):
             return SourceCode(source=commands)
         elif callable(commands):
             return SourceCode(func=commands)
@@ -454,7 +435,7 @@ class _Metas(AttributeForwardMeta, LazyAttributeMeta):
     pass
 
 
-class VariantResourceHelper(six.with_metaclass(_Metas, VariantResource)):
+class VariantResourceHelper(VariantResource, metaclass=_Metas):
     """Helper class for implementing variants that inherit properties from their
     parent package.
 
