@@ -2,12 +2,10 @@
 # Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 from rez.serialise import FileFormat
 from rez.package_resources import help_schema, late_bound
 from rez.vendor.schema.schema import Schema, Optional, And, Or, Use
-from rez.vendor.version.version import Version
+from rez.version import Version
 from rez.utils.schema import extensible_schema_dict
 from rez.utils.sourcecode import SourceCode
 from rez.utils.formatting import PackageRequest, indent, \
@@ -15,10 +13,6 @@ from rez.utils.formatting import PackageRequest, indent, \
 from rez.utils.schema import Required
 from rez.utils.yaml import dump_yaml
 from pprint import pformat
-from rez.vendor.six import six
-
-
-basestring = six.string_types[0]
 
 
 # preferred order of keys in a package definition file
@@ -49,19 +43,19 @@ package_key_order = [
     'previous_revision']
 
 
-version_schema = Or(basestring, And(Version, Use(str)))
+version_schema = Or(str, And(Version, Use(str)))
 
-package_request_schema = Or(basestring, And(PackageRequest, Use(str)))
+package_request_schema = Or(str, And(PackageRequest, Use(str)))
 
-source_code_schema = Or(SourceCode, And(basestring, Use(SourceCode)))
+source_code_schema = Or(SourceCode, And(str, Use(SourceCode)))
 
 tests_schema = Schema({
-    Optional(basestring): Or(
-        Or(basestring, [basestring]),
+    Optional(str): Or(
+        Or(str, [str]),
         extensible_schema_dict({
-            "command": Or(basestring, [basestring]),
+            "command": Or(str, [str]),
             Optional("requires"): [package_request_schema],
-            Optional("run_on"): Or(basestring, [basestring]),
+            Optional("run_on"): Or(str, [str]),
             Optional("on_variants"): Or(
                 bool,
                 {
@@ -76,11 +70,11 @@ tests_schema = Schema({
 
 # package serialisation schema
 package_serialise_schema = Schema({
-    Required("name"):                   basestring,
+    Required("name"):                   str,
     Optional("version"):                version_schema,
-    Optional("description"):            basestring,
-    Optional("authors"):                [basestring],
-    Optional("tools"):                  late_bound([basestring]),
+    Optional("description"):            str,
+    Optional("authors"):                [str],
+    Optional("tools"):                  late_bound([str]),
 
     Optional('requires'):               late_bound([package_request_schema]),
     Optional('build_requires'):         late_bound([package_request_schema]),
@@ -100,19 +94,19 @@ package_serialise_schema = Schema({
     Optional('pre_test_commands'):      source_code_schema,
 
     Optional("help"):                   late_bound(help_schema),
-    Optional("uuid"):                   basestring,
+    Optional("uuid"):                   str,
     Optional("config"):                 dict,
 
     Optional('tests'):                  late_bound(tests_schema),
 
     Optional("timestamp"):              int,
     Optional('revision'):               object,
-    Optional('changelog'):              basestring,
-    Optional('release_message'):        Or(None, basestring),
+    Optional('changelog'):              str,
+    Optional('release_message'):        Or(None, str),
     Optional('previous_version'):       version_schema,
     Optional('previous_revision'):      object,
 
-    Optional(basestring):               object
+    Optional(str):               object
 })
 
 
@@ -121,7 +115,7 @@ def dump_package_data(data, buf, format_=FileFormat.py, skip_attributes=None):
 
     Args:
         data (dict): Data source - must conform to `package_serialise_schema`.
-        buf (file-like object): Destination stream.
+        buf (typing.IO): Destination stream.
         format_ (`FileFormat`): Format to dump data in.
         skip_attributes (list of str): List of attributes to not print.
     """
