@@ -2,15 +2,11 @@
 # Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function, absolute_import
-
 from rez.packages import get_latest_package
-from rez.vendor.version.version import Version
+from rez.version import Version
 from rez.vendor.distlib.database import DistributionPath
-from rez.vendor.enum.enum import Enum
 from rez.vendor.packaging.version import Version as PackagingVersion
 from rez.vendor.packaging.specifiers import Specifier
-from rez.vendor.six.six import StringIO
 from rez.resolved_context import ResolvedContext
 from rez.utils.execution import Popen
 from rez.utils.pip import get_rez_requirements, pip_to_rez_package_name, \
@@ -23,14 +19,16 @@ from rez.package_maker import make_package
 from rez.config import config
 
 import os
-from pipes import quote
+from shlex import quote
 from pprint import pformat
+from enum import Enum
 import re
 import shutil
 import subprocess
 import sys
 from tempfile import mkdtemp
 from textwrap import dedent
+from io import StringIO
 
 
 PIP_SPECIFIER = Specifier(">=19")  # rez pip only compatible with pip>=19
@@ -137,7 +135,7 @@ def find_python_in_context(context):
     # accidentally find a system python install.
     #
     context = context.copy()
-    context.append_sys_path = False  # https://github.com/nerdvegas/rez/issues/826
+    context.append_sys_path = False  # #826
 
     python_package = context.get_resolved_package("python")
     assert python_package
@@ -388,8 +386,7 @@ def pip_install_package(source_name, pip_version=None, python_version=None,
                 src = os.path.join(targetpath, rel_src)
                 dest = os.path.join(path, rel_dest)
 
-                if not os.path.exists(os.path.dirname(dest)):
-                    os.makedirs(os.path.dirname(dest))
+                os.makedirs(os.path.dirname(dest), exist_ok=True)
 
                 shutil.copyfile(src, dest)
 
@@ -430,7 +427,7 @@ def pip_install_package(source_name, pip_version=None, python_version=None,
             # Make the package use hashed variants. This is required because we
             # can't control what ends up in its variants, and that can easily
             # include problematic chars (>, +, ! etc).
-            # TODO: https://github.com/nerdvegas/rez/issues/672
+            # TODO: #672
             #
             pkg.hashed_variants = True
 
@@ -541,7 +538,7 @@ def _get_distribution_files_mapping(distribution, targetdir):
             4. Try rez-pip install again.
 
             If path remapping is not enough, consider submitting a new issue
-            via https://github.com/nerdvegas/rez/issues/new
+            via https://github.com/AcademySoftwareFoundation/rez/issues/new
             """.format(dist_record, rel_src, tokenised_path)
             print_error(dedent(try_this_message).lstrip())
 
