@@ -10,15 +10,16 @@ from rez.utils.formatting import columnise
 from rez.utils.schema import dict_to_schema
 from rez.utils.data_utils import LazySingleton, cached_property, deep_update
 from rez.utils.logging_ import print_debug, print_warning
-from rez.vendor.six import six
 from rez.exceptions import RezPluginError
 from zipimport import zipimporter
 import pkgutil
 import os.path
 import sys
 
-
-basestring = six.string_types[0]
+if sys.version_info[:2] >= (3, 8):
+    from importlib.metadata import entry_points
+else:
+    from rez.vendor.importlib_metadata import entry_points
 
 
 # modified from pkgutil standard library:
@@ -113,8 +114,12 @@ class RezPluginType(object):
         self.plugin_modules[plugin_name] = plugin_module
 
     def load_plugins(self):
+        self.load_plugins_from_namespace()
+        self.load_plugins_from_entry_points()
+
+    def load_plugins_from_namespace(self):
         import pkgutil
-        from rez.backport.importlib import import_module
+        from importlib import import_module
         type_module_name = 'rezplugins.' + self.type_name
         package = import_module(type_module_name)
 
@@ -123,7 +128,7 @@ class RezPluginType(object):
         # extend_path, above). this means that `walk_packages` will walk over all
         # modules on the search path at the same level (.e.g in a
         # 'rezplugins/type_name' sub-directory).
-        paths = [package.__path__] if isinstance(package.__path__, basestring) \
+        paths = [package.__path__] if isinstance(package.__path__, str) \
             else package.__path__
 
         # reverse plugin path order, so that custom plugins have a chance to
@@ -157,57 +162,89 @@ class RezPluginType(object):
                 if config.debug("plugins"):
                     print_debug("loading %s plugin at %s: %s..."
                                 % (self.type_name, path, modname))
+
                 try:
-                    # nerdvegas/rez#218
-                    # load_module will force reload the module if it's
-                    # already loaded, so check for that
                     plugin_module = sys.modules.get(modname)
                     if plugin_module is None:
-                        loader = importer.find_module(modname)
-                        plugin_module = loader.load_module(modname)
-
-                    elif os.path.dirname(plugin_module.__file__) != path:
-                        if config.debug("plugins"):
-                            # this should not happen but if it does, tell why.
-                            print_warning(
-                                "plugin module %s is not loaded from current "
-                                "load path but reused from previous imported "
-                                "path: %s" % (modname, plugin_module.__file__))
-
-                    if (hasattr(plugin_module, "register_plugin")
-                            and callable(plugin_module.register_plugin)):
-
-                        plugin_class = plugin_module.register_plugin()
-                        if plugin_class is not None:
-                            self.register_plugin(plugin_name,
-                                                 plugin_class,
-                                                 plugin_module)
-                        else:
-                            if config.debug("plugins"):
-                                print_warning(
-                                    "'register_plugin' function at %s: %s did "
-                                    "not return a class." % (path, modname))
-                    else:
-                        if config.debug("plugins"):
-                            print_warning(
-                                "no 'register_plugin' function at %s: %s"
-                                % (path, modname))
-
-                        # delete from sys.modules?
+                        loader = importer.find_spec(modname)
+                        plugin_module = loader.loader.load_module(modname)
 
+                    self.register_plugin_module(plugin_name, plugin_module, path)
+                    self.load_config_from_plugin(plugin_module)
                 except Exception as e:
-                    nameish = modname.split('.')[-1]
-                    self.failed_plugins[nameish] = str(e)
-                    if config.debug("plugins"):
-                        import traceback
-                        from rez.vendor.six.six import StringIO
-                        out = StringIO()
-                        traceback.print_exc(file=out)
-                        print_debug(out.getvalue())
+                    self.print_log_plugins_error(modname, e)
 
-            # load config
-            data, _ = _load_config_from_filepaths([os.path.join(path, "rezconfig")])
-            deep_update(self.config_data, data)
+    def load_plugins_from_entry_points(self):
+        entry_point_name = f"rez.plugins.{self.type_name}"
+        if config.debug("plugins"):
+            print_debug("searching plugin for entry point %r...", entry_point_name)
+
+        if sys.version_info[:2] >= (3, 8) and sys.version_info[:2] <= (3, 9):
+            discovered_plugins = entry_points().get(entry_point_name, [])
+        else:
+            discovered_plugins = entry_points(group=entry_point_name)
+
+        for plugin in discovered_plugins:
+            if config.debug("plugins"):
+                print_debug("loading %s plugin for %r..."
+                            % (self.type_name, f"{plugin.name} = {plugin.value!r}"))
+            try:
+                plugin_name = plugin.name
+                plugin = plugin.load()
+                plugin_path = os.path.dirname(plugin.__file__)
+                self.register_plugin_module(plugin_name, plugin, plugin_path)
+                self.load_config_from_plugin(plugin)
+            except Exception as e:
+                self.print_log_plugins_error(plugin.__name__, e)
+
+    def print_log_plugins_error(self, module_name, error):
+        nameish = module_name.split('.')[-1]
+        self.failed_plugins[nameish] = str(error)
+
+        if not config.debug("plugins"):
+            return
+
+        import traceback
+        from io import StringIO
+        out = StringIO()
+        traceback.print_exc(file=out)
+        print_debug(out.getvalue())
+
+    def load_config_from_plugin(self, plugin):
+        plugin_path = os.path.dirname(plugin.__file__)
+        data, _ = _load_config_from_filepaths([os.path.join(plugin_path, "rezconfig")])
+        deep_update(self.config_data, data)
+
+    def register_plugin_module(self, plugin_name, plugin_module, plugin_path):
+        module_name = plugin_module.__name__
+        if os.path.dirname(plugin_module.__file__) != plugin_path:
+            if config.debug("plugins"):
+                # this should not happen but if it does, tell why.
+                print_warning(
+                    "plugin module %s is not loaded from current "
+                    "load path but reused from previous imported "
+                    "path: %s" % (module_name, plugin_module.__file__))
+
+        if (hasattr(plugin_module, "register_plugin")
+                and callable(plugin_module.register_plugin)):
+
+            plugin_class = plugin_module.register_plugin()
+            if plugin_class is not None:
+                self.register_plugin(
+                    plugin_name,
+                    plugin_class,
+                    plugin_module
+                )
+            else:
+                if config.debug("plugins"):
+                    print_warning(
+                        "'register_plugin' function at %s: %s did "
+                        "not return a class." % (plugin_path, module_name))
+        else:
+            if config.debug("plugins"):
+                print_warning(
+                    "no 'register_plugin' function at %s: %s"
+                    % (plugin_path, module_name))
 
     def get_plugin_class(self, plugin_name):
         """Returns the class registered under the given plugin name."""
@@ -317,7 +354,12 @@ class RezPluginManager(object):
                     module_path = os.path.join(importer.archive, name)
 
             else:
-                module_path = os.path.join(importer.path, name)
+                try:
+                    module_path = os.path.join(importer.path, name)
+                # Ignore execution failures due to missing `importer.path`,
+                # when rez is packaged as a single application via Pyinstaller or PyOxidizer.
+                except AttributeError:
+                    continue
                 init_path = os.path.join(module_path, "rezplugins", "__init__.py")
                 if not os.path.isfile(init_path):
                     continue
@@ -378,7 +420,7 @@ class RezPluginManager(object):
         """Return a list of plugins for the given type that failed to load.
 
         Returns:
-            List of 2-tuples:
+            tuple: List of 2-tuples:
             name (str): Name of the plugin.
             reason (str): Error message.
         """
