@@ -2,8 +2,6 @@
 # Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 from rez import __version__, module_root_path
 from rez.package_repository import package_repository_manager
 from rez.solver import SolverCallbackReturn
@@ -21,7 +19,7 @@ from rez.utils.filesystem import TempDirs, is_subdirectory, canonical_path
 from rez.utils.memcached import pool_memcached_connections
 from rez.utils.logging_ import print_error, print_warning
 from rez.utils.which import which
-from rez.rex import RexExecutor, Python, OutputStyle
+from rez.rex import RexExecutor, Python, OutputStyle, literal
 from rez.rex_bindings import VersionBinding, VariantBinding, \
     VariantsBinding, RequirementsBinding, EphemeralsBinding, intersects
 from rez import package_order
@@ -35,18 +33,17 @@ from rez.exceptions import ResolvedContextError, PackageCommandError, \
 from rez.utils.graph_utils import write_dot, write_compacted, \
     read_graph_from_string
 from rez.utils.resolve_graph import failure_detail_from_graph
-from rez.vendor.six import six
-from rez.vendor.version.version import VersionRange
-from rez.vendor.version.requirement import Requirement
-from rez.vendor.enum import Enum
+from rez.version import VersionRange
+from rez.version import Requirement
 from rez.vendor import yaml
-from rez.utils import json
 from rez.utils.yaml import dump_yaml
 from rez.utils.platform_ import platform_
 
 from contextlib import contextmanager
 from functools import wraps
+from enum import Enum
 import getpass
+import json
 import socket
 import threading
 import time
@@ -55,28 +52,34 @@ import os
 import os.path
 
 
-basestring = six.string_types[0]
-
-
 class RezToolsVisibility(Enum):
     """Determines if/how rez cli tools are added back to PATH within a
-    resolved environment."""
-    never = 0               # Don't expose rez in resolved env
-    append = 1              # Append to PATH in resolved env
-    prepend = 2             # Prepend to PATH in resolved env
+    resolved environment.
+    """
+    #: Don't expose rez in resolved env
+    never = 0
+    #: Append to PATH in resolved env
+    append = 1
+    #: Prepend to PATH in resolved env
+    prepend = 2
 
 
 class SuiteVisibility(Enum):
     """Defines what suites on $PATH stay visible when a new rez environment is
-    resolved."""
-    never = 0               # Don't attempt to keep any suites visible in a new env
-    always = 1              # Keep suites visible in any new env
-    parent = 2              # Keep only the parent suite of a tool visible
-    parent_priority = 3     # Keep all suites visible and the parent takes precedence
+    resolved.
+    """
+    #: Don't attempt to keep any suites visible in a new env
+    never = 0
+    #: Keep suites visible in any new env
+    always = 1
+    #: Keep only the parent suite of a tool visible
+    parent = 2
+    #: Keep all suites visible and the parent takes precedence
+    parent_priority = 3
 
 
 class PatchLock(Enum):
-    """ Enum to represent the 'lock type' used when patching context objects.
+    """Enum to represent the 'lock type' used when patching context objects.
     """
     no_lock = ("No locking", -1)
     lock_2 = ("Minor version updates only (X.*)", 1)
@@ -107,7 +110,7 @@ def get_lock_request(name, version, patch_lock, weak=True):
         patch_lock (PatchLock): Lock type to apply.
 
     Returns:
-        `PackageRequest` object, or None if there is no equivalent request.
+        typing.Optional[PackageRequest]: PackageRequest object, or None if there is no equivalent request.
     """
     ch = '~' if weak else ''
     if patch_lock == PatchLock.lock:
@@ -131,7 +134,7 @@ class ResolvedContext(object):
     command within a configured python namespace, without spawning a child
     shell.
     """
-    serialize_version = (4, 7)
+    serialize_version = (4, 9)
     tmpdir_manager = TempDirs(config.context_tmpdir, prefix="rez_context_")
     context_tracking_payload = None
     context_tracking_lock = threading.Lock()
@@ -160,49 +163,51 @@ class ResolvedContext(object):
             return SolverCallbackReturn.keep_going, ''
 
     def __init__(self, package_requests, verbosity=0, timestamp=None,
-                 building=False, caching=None, package_paths=None,
+                 building=False, testing=False, caching=None, package_paths=None,
                  package_filter=None, package_orderers=None, max_fails=-1,
                  add_implicit_packages=True, time_limit=-1, callback=None,
                  package_load_callback=None, buf=None, suppress_passive=False,
-                 print_stats=False, package_caching=None):
+                 print_stats=False, package_caching=None, package_cache_async=None):
         """Perform a package resolve, and store the result.
 
         Args:
-            package_requests: List of strings or PackageRequest objects
-                representing the request.
-            verbosity: Verbosity level. One of [0,1,2].
-            timestamp: Ignore packages released after this epoch time. Packages
+            package_requests (list[typing.Union[str, PackageRequest]]): request
+            verbosity (int): Verbosity level. One of [0,1,2].
+            timestamp (float): Ignore packages released after this epoch time. Packages
                 released at exactly this time will not be ignored.
-            building: True if we're resolving for a build.
-            caching: If True, cache(s) may be used to speed the resolve. If
-                False, caches will not be used. If None, config.resolve_caching
+            building (bool): True if we're resolving for a build.
+            testing (bool): True if we're resolving for a test (rez-test).
+            caching (bool): If True, cache(s) may be used to speed the resolve. If
+                False, caches will not be used. If None, :data:`resolve_caching`
                 is used.
-            package_paths: List of paths to search for pkgs, defaults to
-                config.packages_path.
-            package_filter (`PackageFilterBase`): Filter used to exclude certain
-                packages. Defaults to settings from config.package_filter. Use
-                `package_filter.no_filter` to remove all filtering.
-            package_orderers (list of `PackageOrder`): Custom package ordering.
-                Defaults to settings from config.package_orderers.
-            add_implicit_packages: If True, the implicit package list defined
-                by config.implicit_packages is appended to the request.
+            package_paths (list[str]): List of paths to search for pkgs, defaults to
+                :data:`packages_path`.
+            package_filter (PackageFilterList): Filter used to exclude certain
+                packages. Defaults to settings from :data:`package_filter`. Use
+                :data:`rez.package_filter.no_filter` to remove all filtering.
+            package_orderers (list[PackageOrder]): Custom package ordering.
+                Defaults to settings from :data:`package_orderers`.
+            add_implicit_packages (bool): If True, the implicit package list defined
+                by :data:`implicit_packages` is appended to the request.
             max_fails (int): Abort the resolve if the number of failed steps is
                 greater or equal to this number. If -1, does not abort.
             time_limit (int): Abort the resolve if it takes longer than this
                 many seconds. If -1, there is no time limit.
-            callback: See `Solver`.
+            callback: See :class:`.Solver`.
             package_load_callback: If not None, this callable will be called
                 prior to each package being loaded. It is passed a single
-                `Package` object.
-            buf (file-like object): Where to print verbose output to, defaults
+                :class:`.Package` object.
+            buf (typing.IO): Where to print verbose output to, defaults
                 to stdout.
             suppress_passive (bool): If True, don't print debugging info that
                 has had no effect on the solve. This argument only has an
-                effect if `verbosity` > 2.
+                effect if ``verbosity`` > 2.
             print_stats (bool): If True, print advanced solver stats at the end.
             package_caching (bool|None): If True, apply package caching settings
                 as per the config. If None, enable as determined by config
-                setting 'package_cache_during_build'.
+                setting :data:`package_cache_during_build`.
+            package_cache_async (bool|None): If True, cache packages asynchronously.
+                If None, use the config setting :data:`package_cache_async`
         """
         self.load_path = None
 
@@ -210,13 +215,14 @@ class ResolvedContext(object):
         self.requested_timestamp = timestamp
         self.timestamp = self.requested_timestamp or int(time.time())
         self.building = building
+        self.testing = testing
         self.implicit_packages = []
         self.caching = config.resolve_caching if caching is None else caching
         self.verbosity = verbosity
 
         self._package_requests = []
         for req in package_requests:
-            if isinstance(req, basestring):
+            if isinstance(req, str):
                 req = PackageRequest(req)
             self._package_requests.append(req)
 
@@ -231,7 +237,7 @@ class ResolvedContext(object):
         self.package_filter = (PackageFilterList.singleton if package_filter is None
                                else package_filter)
 
-        self.package_orderers = (
+        self.package_orderers = PackageOrderList(
             PackageOrderList.singleton if package_orderers is None
             else package_orderers
         )
@@ -244,9 +250,12 @@ class ResolvedContext(object):
                 package_caching = config.package_cache_during_build
             else:
                 package_caching = True
-
         self.package_caching = package_caching
 
+        if package_cache_async is None:
+            package_cache_async = config.package_cache_async
+        self.package_cache_async = package_cache_async
+
         # patch settings
         self.default_patch_lock = PatchLock.no_lock
         self.patch_locks = {}
@@ -357,7 +366,7 @@ class ResolvedContext(object):
         """Return the current status of the context.
 
         Returns:
-            ResolverStatus.
+            ResolverStatus:
         """
         return self.status_
 
@@ -369,7 +378,7 @@ class ResolvedContext(object):
                 to the result.
 
         Returns:
-            List of `PackageRequest` objects.
+            list[PackageRequest]:
         """
         if include_implicit:
             return self._package_requests + self.implicit_packages
@@ -381,7 +390,7 @@ class ResolvedContext(object):
         """Get packages in the resolve.
 
         Returns:
-            List of `Variant` objects, or None if the resolve failed.
+            typing.Optional[list[Variant]]: Resolved variant objects, or None if the resolve failed.
         """
         return self._resolved_packages
 
@@ -390,7 +399,7 @@ class ResolvedContext(object):
         """Get non-conflict ephemerals in the resolve.
 
         Returns:
-            List of `Requirement` objects, or None if the resolve failed.
+            typing.Optional[list[Requirement]]: Requirement objects, or None if the resolve failed.
         """
         return self._resolved_ephemerals
 
@@ -438,7 +447,7 @@ class ResolvedContext(object):
         """Returns a `Variant` object or None if the package is not in the
         resolve.
         """
-        pkgs = [x for x in self._resolved_packages if x.name == name]
+        pkgs = [x for x in (self._resolved_packages or []) if x.name == name]
         return pkgs[0] if pkgs else None
 
     def copy(self):
@@ -457,11 +466,11 @@ class ResolvedContext(object):
             package_names (list of str): Only retarget these packages. If None,
                 retarget all packages.
             skip_missing (bool): If True, skip retargeting of variants that
-                cannot be found in `package_paths`. By default, a
-                `PackageNotFoundError` is raised.
+                cannot be found in ``package_paths``. By default, a
+                :exc:`.PackageNotFoundError` is raised.
 
         Returns:
-            ResolvecContext`: The retargeted context.
+            ResolvedContext: The retargeted context.
         """
         retargeted_variants = []
 
@@ -529,9 +538,9 @@ class ResolvedContext(object):
         in the order that they appear in `package_requests`.
 
         Args:
-            package_requests (list of str or list of `PackageRequest`):
+            package_requests (list[typing.Union[str, PackageRequest]):
                 Overriding requests.
-            package_subtractions (list of str): Any original request with a
+            package_subtractions (list[str]): Any original request with a
                 package name in this list is removed, before the new requests
                 are added.
             strict (bool): If True, the current context's resolve is used as the
@@ -540,12 +549,12 @@ class ResolvedContext(object):
                 and further - for example, rank=3 means that only version patch
                 numbers are allowed to increase, major and minor versions will
                 not change. This is only applied to packages that have not been
-                explicitly overridden in `package_requests`. If rank <= 1, or
-                `strict` is True, rank is ignored.
+                explicitly overridden in ``package_requests``. If rank <= 1, or
+                ``strict`` is True, rank is ignored.
 
         Returns:
-            List of `PackageRequest` objects that can be used to construct a
-            new `ResolvedContext` object.
+            list[PackageRequest]: PackageRequests objects that can be used to construct a
+            new :class:`ResolvedContext` object.
         """
         # assemble source request
         if strict:
@@ -578,7 +587,7 @@ class ResolvedContext(object):
             request_ = []
 
             for req in package_requests:
-                if isinstance(req, basestring):
+                if isinstance(req, str):
                     req = PackageRequest(req)
 
                 if req.name in request_dict:
@@ -650,11 +659,7 @@ class ResolvedContext(object):
         """Save the context to a buffer."""
         doc = self.to_dict()
 
-        if config.rxt_as_yaml:
-            content = dump_yaml(doc)
-        else:
-            content = json.dumps(doc, indent=4, separators=(",", ": "),
-                                 sort_keys=True)
+        content = json.dumps(doc, indent=4, separators=(",", ": "), sort_keys=True)
 
         buf.write(content)
 
@@ -663,7 +668,7 @@ class ResolvedContext(object):
         """Get the context for the current env, if there is one.
 
         Returns:
-            `ResolvedContext`: Current context, or None if not in a resolved env.
+            ResolvedContext: Current context, or None if not in a resolved env.
         """
         filepath = os.getenv("REZ_RXT_FILE")
         if not filepath or not os.path.exists(filepath):
@@ -717,15 +722,16 @@ class ResolvedContext(object):
         of a package is ignored.
 
         Returns:
-            A dict containing:
+            dict: A dict containing:
+
             - 'newer_packages': A dict containing items:
-              - package name (str);
-              - List of `Package` objects. These are the packages up to and
-                including the newer package in `self`, in ascending order.
+                - package name (str);
+                - List of `Package` objects. These are the packages up to and
+                  including the newer package in `self`, in ascending order.
             - 'older_packages': A dict containing:
-              - package name (str);
-              - List of `Package` objects. These are the packages down to and
-                including the older package in `self`, in descending order.
+                - package name (str);
+                - List of `Package` objects. These are the packages down to and
+                  including the older package in `self`, in descending order.
             - 'added_packages': Set of `Package` objects present in `self` but
                not in `other`;
             - 'removed_packages': Set of `Package` objects present in `other`,
@@ -795,7 +801,7 @@ class ResolvedContext(object):
         """Prints a message summarising the contents of the resolved context.
 
         Args:
-            buf (file-like object): Where to print this info to.
+            buf (typing.IO): Where to print this info to.
             verbosity (bool): Verbose mode.
             source_order (bool): If True, print resolved packages in the order
                 they are sourced, rather than alphabetical order.
@@ -984,8 +990,9 @@ class ResolvedContext(object):
         """Print the difference between the resolve of two contexts.
 
         Args:
-            other (`ResolvedContext`): Context to compare to.
+            other (ResolvedContext): Context to compare to.
             heading: One of:
+
                 - None: Do not display a heading;
                 - True: Display the filename of each context as a heading, if
                   both contexts have a filepath;
@@ -1107,9 +1114,12 @@ class ResolvedContext(object):
     def get_environ(self, parent_environ=None):
         """Get the environ dict resulting from interpreting this context.
 
-        @param parent_environ Environment to interpret the context within,
-            defaults to os.environ if None.
-        @returns The environment dict generated by this context, when
+        Args:
+            parent_environ: Environment to interpret the context within,
+                defaults to os.environ if None.
+
+        Returns:
+            The environment dict generated by this context, when
             interpreted in a python rex interpreter.
         """
         interp = Python(target_environ={}, passive=True)
@@ -1127,7 +1137,7 @@ class ResolvedContext(object):
                 packages that were also present in the request.
 
         Returns:
-            Dict of {pkg-name: (variant, value)}.
+            Dict of ``{pkg-name: (variant, value)}``.
         """
         values = {}
         requested_names = [x.name for x in self._package_requests
@@ -1150,7 +1160,7 @@ class ResolvedContext(object):
                 that were also present in the request.
 
         Returns:
-            Dict of {pkg-name: (variant, [tools])}.
+            Dict of ``{pkg-name: (variant, [tools])}``.
         """
         return self.get_key("tools", request_only=request_only)
 
@@ -1184,7 +1194,7 @@ class ResolvedContext(object):
                 that were also present in the request.
 
         Returns:
-            Dict of {tool-name: set([Variant])}.
+            Dict of ``{tool-name: set([Variant])}``.
         """
         from collections import defaultdict
 
@@ -1206,7 +1216,7 @@ class ResolvedContext(object):
                 type is used.
             parent_environ (dict): Environment to interpret the context within,
                 defaults to os.environ if None.
-            style (): Style to format shell code in.
+            style (OutputStyle): Style to format shell code in.
         """
         executor = self._create_executor(interpreter=create_shell(shell),
                                          parent_environ=parent_environ)
@@ -1223,7 +1233,7 @@ class ResolvedContext(object):
         context. This is provided mainly for testing purposes.
 
         Args:
-            parent_environ Environment to interpret the context within,
+            parent_environ: Environment to interpret the context within,
                 defaults to os.environ if None.
 
         Returns:
@@ -1325,7 +1335,7 @@ class ResolvedContext(object):
             Popen_args: args to pass to the shell process object constructor.
 
         Returns:
-            `subprocess.Popen` object for the shell process.
+            subprocess.Popen: Subprocess object for the shell process.
         """
         def _actions_callback(executor):
             executor.execute_code(code, filename=filename)
@@ -1383,8 +1393,11 @@ class ResolvedContext(object):
             Popen_args: args to pass to the shell process object constructor.
 
         Returns:
-            If blocking: A 3-tuple of (returncode, stdout, stderr);
-            If non-blocking - A subprocess.Popen object for the shell process.
+            If blocking, a 3-tuple of (returncode, stdout, stderr).
+                Note that if you want to get anything other than None for stdout
+                and/or stderr, you need to give stdout=PIPE and/or stderr=PIPE.
+
+            If non-blocking, a subprocess.Popen object for the shell process.
         """
         sh = create_shell(shell)
 
@@ -1441,7 +1454,7 @@ class ResolvedContext(object):
 
         # write out the native context file
         context_code = executor.get_output()
-        with open(context_file, 'w') as f:
+        with open(context_file, 'w', encoding="utf-8") as f:
             f.write(context_code)
 
         quiet = quiet or \
@@ -1521,9 +1534,10 @@ class ResolvedContext(object):
             data["patch_locks"] = dict((k, v.name) for k, v in self.patch_locks)
 
         if _add("package_orderers"):
-            package_orderers = [package_order.to_pod(x)
-                                for x in (self.package_orderers or [])]
-            data["package_orderers"] = package_orderers or None
+            if self.package_orderers:
+                data["package_orderers"] = self.package_orderers.to_pod()
+            else:
+                data["package_orderers"] = None
 
         if _add("package_filter"):
             data["package_filter"] = self.package_filter.to_pod()
@@ -1541,6 +1555,7 @@ class ResolvedContext(object):
             timestamp=self.timestamp,
             requested_timestamp=self.requested_timestamp,
             building=self.building,
+            testing=self.testing,
             caching=self.caching,
             implicit_packages=list(map(str, self.implicit_packages)),
             package_requests=list(map(str, self._package_requests)),
@@ -1548,6 +1563,7 @@ class ResolvedContext(object):
 
             append_sys_path=self.append_sys_path,
             package_caching=self.package_caching,
+            package_cache_async=self.package_cache_async,
 
             default_patch_lock=self.default_patch_lock.name,
 
@@ -1681,7 +1697,7 @@ class ResolvedContext(object):
 
         data = d.get("package_orderers")
         if data:
-            r.package_orderers = [package_order.from_pod(x) for x in data]
+            r.package_orderers = PackageOrderList([package_order.from_pod(x) for x in data])
         else:
             r.package_orderers = None
 
@@ -1704,6 +1720,13 @@ class ResolvedContext(object):
             req = Requirement(eph_str)
             r._resolved_ephemerals.append(req)
 
+        # -- SINCE SERIALIZE VERSION 4.8
+
+        r.package_cache_async = d.get("package_cache_async", True)
+
+        # -- SINCE SERIALIZE 4.9
+        r.testing = d.get("testing", False)
+
         # <END SERIALIZATION>
 
         # track context usage
@@ -1832,13 +1855,16 @@ class ResolvedContext(object):
                 not self.success:
             return
 
-        # see PackageCache.add_variants_async
+        # see PackageCache.add_variants
         if not system.is_production_rez_install:
             return
 
         pkgcache = self._get_package_cache()
         if pkgcache:
-            pkgcache.add_variants_async(self.resolved_packages)
+            pkgcache.add_variants(
+                self.resolved_packages,
+                self.package_cache_async,
+            )
 
     @classmethod
     def _init_context_tracking_payload_base(cls):
@@ -1860,7 +1886,7 @@ class ResolvedContext(object):
         # remove fields with unexpanded env-vars, or empty string
         def _del(value):
             return (
-                isinstance(value, basestring)
+                isinstance(value, str)
                 and (not value or ENV_VAR_REGEX.search(value))
             )
 
@@ -1939,6 +1965,7 @@ class ResolvedContext(object):
             self.pre_resolve_bindings = {
                 "system": system,
                 "building": self.building,
+                "testing": self.testing,
                 "request": RequirementsBinding(self._package_requests),
                 "implicits": RequirementsBinding(self.implicit_packages),
                 "intersects": intersects
@@ -1959,6 +1986,7 @@ class ResolvedContext(object):
         request_str = ' '.join(str(x) for x in self._package_requests)
         implicit_str = ' '.join(str(x) for x in self.implicit_packages)
         resolve_str = ' '.join(x.qualified_package_name for x in resolved_pkgs)
+        local_packages_str = ' '.join(x.qualified_package_name for x in resolved_pkgs if x.is_local)
         req_timestamp_str = str(self.requested_timestamp or 0)
         package_paths_str = executor.interpreter.pathsep.join(
             normalized(x) for x in self.package_paths
@@ -1970,8 +1998,8 @@ class ResolvedContext(object):
         executor.setenv("REZ_USED_VERSION", self.rez_version)
         executor.setenv("REZ_USED_TIMESTAMP", str(self.timestamp))
         executor.setenv("REZ_USED_REQUESTED_TIMESTAMP", req_timestamp_str)
-        executor.setenv("REZ_USED_REQUEST", request_str)
-        executor.setenv("REZ_USED_IMPLICIT_PACKAGES", implicit_str)
+        executor.setenv("REZ_USED_REQUEST", literal(request_str))
+        executor.setenv("REZ_USED_IMPLICIT_PACKAGES", literal(implicit_str))
         executor.setenv("REZ_USED_RESOLVE", resolve_str)
         executor.setenv("REZ_USED_PACKAGES_PATH", package_paths_str)
 
@@ -1979,6 +2007,9 @@ class ResolvedContext(object):
             eph_resolve_str = ' '.join(str(x) for x in ephemerals)
             executor.setenv("REZ_USED_EPH_RESOLVE", eph_resolve_str)
 
+        if local_packages_str:
+            executor.setenv("REZ_USED_LOCAL_RESOLVE", local_packages_str)
+
         if self.building:
             executor.setenv("REZ_BUILD_ENV", "1")
 
@@ -2081,7 +2112,8 @@ class ResolvedContext(object):
                 commands.set_package(pkg)
 
                 try:
-                    executor.execute_code(commands, isolate=True)
+                    with executor.reset_globals():
+                        executor.execute_code(commands)
                 except exc_type as e:
                     exc = e
 
