@@ -1,28 +1,19 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 Read and write data from file. File caching via a memcached server is supported.
 """
 from contextlib import contextmanager
+from enum import Enum
 from inspect import isfunction, ismodule
 import sys
 import stat
 import os
 import os.path
 import threading
+from io import StringIO
 
 from rez.package_resources import package_rex_keys
 from rez.utils.scope import ScopeContext
@@ -32,12 +23,9 @@ from rez.utils.data_utils import ModifyList
 from rez.exceptions import ResourceError, InvalidPackageError
 from rez.utils.memcached import memcached
 from rez.utils.execution import add_sys_paths
-from rez.utils import py23
+from rez.util import get_function_arg_names
 from rez.config import config
 from rez.vendor.atomicwrites import atomic_write
-from rez.vendor.enum import Enum
-from rez.vendor.six.six.moves import StringIO
-from rez.vendor.six.six import PY3
 from rez.vendor import yaml
 
 
@@ -79,7 +67,6 @@ def open_file_for_write(filepath, mode=None):
     filepath = os.path.realpath(filepath)
     tmpdir = tmpdir_manager.mkdtemp()
     cache_filepath = os.path.join(tmpdir, os.path.basename(filepath))
-    encoding = {"encoding": "utf-8"} if PY3 else {}
 
     debug_print("Writing to %s (local cache of %s)", cache_filepath, filepath)
 
@@ -93,12 +80,10 @@ def open_file_for_write(filepath, mode=None):
     except:
         pass
 
-    # try atomic write, but that can sometimes fail.
-    # https://github.com/nerdvegas/rez/issues/858
-    #
+    # try atomic write, but that can sometimes fail. See #858
     written = False
     try:
-        with atomic_write(filepath, overwrite=True, **encoding) as f:
+        with atomic_write(filepath, overwrite=True, encoding="utf-8") as f:
             f.write(content)
         written = True
     except:
@@ -106,14 +91,14 @@ def open_file_for_write(filepath, mode=None):
 
     # fallback to standard write
     if not written:
-        with open(filepath, 'w', **encoding) as f:
+        with open(filepath, 'w', encoding="utf-8") as f:
             f.write(content)
 
     if mode is not None:
         os.chmod(filepath, mode)
 
     # write the local fs cache copy
-    with open(cache_filepath, 'w', **encoding) as f:
+    with open(cache_filepath, 'w', encoding="utf-8") as f:
         f.write(content)
 
     file_cache[filepath] = cache_filepath
@@ -124,17 +109,17 @@ def load_from_file(filepath, format_=FileFormat.py, update_data_callback=None,
     """Load data from a file.
 
     Note:
-        Any functions from a .py file will be converted to `SourceCode` objects.
+        Any functions from a .py file will be converted to :class:`.SourceCode` objects.
 
     Args:
         filepath (str): File to load.
-        format_ (`FileFormat`): Format of file contents.
-        update_data_callback (callable): Used to change data before it is
+        format_ (FileFormat): Format of file contents.
+        update_data_callback (typing.Callable): Used to change data before it is
             returned or cached.
         disable_memcache (bool): If True, don't r/w to memcache.
 
     Returns:
-        dict.
+        dict:
     """
     filepath = os.path.realpath(filepath)
     cache_filepath = file_cache.get(filepath)
@@ -199,6 +184,7 @@ _set_objects = threading.local()
 # Default variables to avoid not-defined errors in early-bound attribs
 default_objects = {
     "building": False,
+    "testing": False,
     "build_variant_index": 0,
     "build_variant_requires": []
 }
@@ -237,10 +223,10 @@ def load_py(stream, filepath=None):
     """Load python-formatted data from a stream.
 
     Args:
-        stream (file-like object).
+        stream (typing.IO):
 
     Returns:
-        dict.
+        dict:
     """
     with add_sys_paths(config.package_definition_build_python_paths):
         return _load_py(stream, filepath=filepath)
@@ -286,7 +272,7 @@ def _load_py(stream, filepath=None):
 
 
 class EarlyThis(object):
-    """The 'this' object for @early bound functions.
+    """The ``this`` object for ``@early`` bound functions.
 
     Just exposes raw package data as object attributes.
     """
@@ -311,10 +297,11 @@ def process_python_objects(data, filepath=None):
     """Replace certain values in the given package data dict.
 
     Does things like:
-    * evaluates @early decorated functions, and replaces with return value;
-    * converts functions into `SourceCode` instances so they can be serialized
+
+    * evaluates ``@early`` decorated functions, and replaces with return value;
+    * converts functions into :class:`.SourceCode` instances so they can be serialized
       out to installed packages, and evaluated later;
-    * strips some values (modules, __-leading variables) that are never to be
+    * strips some values (modules, ``__``-leading variables) that are never to be
       part of installed packages.
 
     Returns:
@@ -346,7 +333,7 @@ def process_python_objects(data, filepath=None):
                 fn.__globals__.update(get_objects())
 
                 # execute the function
-                args = py23.get_function_arg_names(func)
+                args = get_function_arg_names(func)
 
                 if len(args) not in (0, 1):
                     raise ResourceError("@early decorated function must "
@@ -414,10 +401,10 @@ def load_yaml(stream, **kwargs):
     """Load yaml-formatted data from a stream.
 
     Args:
-        stream (file-like object).
+        stream (typing.IO):
 
     Returns:
-        dict.
+        dict:
     """
     # if there's an error parsing the yaml, and you pass yaml.load a string,
     # it will print lines of context, but will print "<string>" instead of a
@@ -443,10 +430,10 @@ def load_txt(stream, **kwargs):
     """Load text data from a stream.
 
     Args:
-        stream (file-like object).
+        stream (typing.IO):
 
     Returns:
-        string.
+        str:
     """
     content = stream.read()
     return content
