@@ -14,20 +14,16 @@ from rez.system import system
 from rez.exceptions import RezSystemError
 from rez.rex import EscapedString
 from rez.config import config
-from rez.vendor.six import six
 import os
 import os.path
-import pipes
-
-
-basestring = six.string_types[0]
+from shlex import quote
 
 
 def get_shell_types():
     """Returns the available shell types: bash, tcsh etc.
 
     Returns:
-    List of str: Shells.
+        list[str]: Shells.
     """
     from rez.plugin_managers import plugin_manager
     return list(plugin_manager.get_plugins('shell'))
@@ -37,7 +33,7 @@ def get_shell_class(shell=None):
     """Get the plugin class associated with the given or current shell.
 
     Returns:
-        class: Plugin class for shell.
+        type[Shell]: Plugin class for shell.
     """
     if not shell:
         shell = config.default_shell
@@ -53,7 +49,7 @@ def create_shell(shell=None, **kwargs):
     """Returns a Shell of the given or current type.
 
     Returns:
-        `Shell`: Instance of given shell.
+        Shell: Instance of given shell.
     """
     if not shell:
         shell = config.default_shell
@@ -68,8 +64,7 @@ def create_shell(shell=None, **kwargs):
 class Shell(ActionInterpreter):
     """Class representing a shell, such as bash or tcsh.
     """
-    schema_dict = {
-        "prompt": basestring}
+    schema_dict = {"prompt": str}
 
     @classmethod
     def name(cls):
@@ -120,7 +115,9 @@ class Shell(ActionInterpreter):
         """
         Given a set of options related to shell startup, return the actual
         options that will be applied.
-        @returns 4-tuple representing applied value of each option.
+
+        Returns:
+            tuple: 4-tuple representing applied value of each option.
         """
         raise NotImplementedError
 
@@ -203,8 +200,9 @@ class Shell(ActionInterpreter):
                     pre_command=None, add_rez=True,
                     package_commands_sourced_first=None, **Popen_args):
         """Spawn a possibly interactive subshell.
+
         Args:
-            context:_file File that must be sourced in the new shell, this
+            context_file: File that must be sourced in the new shell, this
                 configures the Rez environment.
             tmpdir: Tempfiles, if needed, should be created within this path.
             rcfile: Custom startup script.
@@ -230,7 +228,7 @@ class Shell(ActionInterpreter):
             popen_args: args to pass to the shell process object constructor.
 
         Returns:
-            A subprocess.Popen object representing the shell process.
+            subprocess.Popen: A subprocess.Popen object representing the shell process.
         """
         raise NotImplementedError
 
@@ -320,8 +318,8 @@ class Shell(ActionInterpreter):
 
 
 class UnixShell(Shell):
-    """
-    A base class for common *nix shells, such as bash and tcsh.
+    r"""
+    A base class for common \*nix shells, such as bash and tcsh.
     """
     rcfile_arg = None
     norc_arg = None
@@ -352,6 +350,7 @@ class UnixShell(Shell):
     def get_startup_sequence(cls, rcfile, norc, stdin, command):
         """
         Return a dict containing:
+
         - 'stdin': resulting stdin setting.
         - 'command': resulting command setting.
         - 'do_rcfile': True if a file should be sourced directly.
@@ -426,11 +425,11 @@ class UnixShell(Shell):
             shell_command = d["command"]
         else:
             if d["stdin"]:
-                assert(self.stdin_arg)
+                assert self.stdin_arg
                 shell_command = "%s %s" % (self.executable, self.stdin_arg)
                 quiet = True
             elif do_rcfile:
-                assert(self.rcfile_arg)
+                assert self.rcfile_arg
                 shell_command = "%s %s" % (self.executable, self.rcfile_arg)
             else:
                 shell_command = self.executable
@@ -498,7 +497,7 @@ class UnixShell(Shell):
 
         cmd = []
         if pre_command:
-            if isinstance(pre_command, basestring):
+            if isinstance(pre_command, str):
                 cmd = pre_command.strip().split()
             else:
                 cmd = pre_command
@@ -507,7 +506,7 @@ class UnixShell(Shell):
         try:
             p = Popen(cmd, env=env, **Popen_args)
         except Exception as e:
-            cmd_str = ' '.join(map(pipes.quote, cmd))
+            cmd_str = ' '.join(map(quote, cmd))
             raise RezSystemError("Error running command:\n%s\n%s"
                                  % (cmd_str, str(e)))
         return p
