@@ -1,20 +1,7 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 from rez.utils.execution import create_forwarding_script
 from rez.exceptions import SuiteError, ResolvedContextError
 from rez.resolved_context import ResolvedContext
@@ -24,7 +11,6 @@ from rez.utils.colorize import warning, critical, Printer, alias as alias_col
 from rez.vendor import yaml
 from rez.vendor.yaml.error import YAMLError
 from rez.utils.yaml import dump_yaml
-from rez.vendor.six import six
 from collections import defaultdict
 import os
 import os.path
@@ -32,9 +18,6 @@ import shutil
 import sys
 
 
-basestring = six.string_types[0]
-
-
 class Suite(object):
     """A collection of contexts.
 
@@ -50,6 +33,7 @@ class Suite(object):
     context's tools override tools from other contexts.
 
     There are several ways to avoid tool name clashes:
+
     - Hide a tool. This removes it from the suite even if it does not clash;
     - Prefix/suffix a context. When you do this, all the tools in the context
       have the prefix/suffix applied;
@@ -165,7 +149,7 @@ class Suite(object):
             names = [x for x in names if _in_request(x)]
 
         if in_resolve:
-            if isinstance(in_resolve, basestring):
+            if isinstance(in_resolve, str):
                 in_resolve = PackageRequest(in_resolve)
 
             def _in_resolve(name):
@@ -311,7 +295,8 @@ class Suite(object):
         """Get the tools exposed by this suite.
 
         Returns:
-            A dict, keyed by aliased tool name, with dict entries:
+            dict: A dict, keyed by aliased tool name, with dict entries:
+
             - tool_name (str): The original, non-aliased name of the tool;
             - tool_alias (str): Aliased tool name (same as key);
             - context_name (str): Name of the context containing the tool;
@@ -365,7 +350,8 @@ class Suite(object):
         Hidden tools are those that have been explicitly hidden via `hide_tool`.
 
         Returns:
-            A list of dicts, where each dict contains:
+            list[dict]: A list of dicts, where each dict contains:
+
             - tool_name (str): The original, non-aliased name of the tool;
             - tool_alias (str): Aliased tool name (same as key);
             - context_name (str): Name of the context containing the tool;
@@ -455,7 +441,7 @@ class Suite(object):
                 raise SuiteError("Cannot save, path exists: %r" % path)
 
         contexts_path = os.path.join(path, "contexts")
-        os.makedirs(contexts_path)
+        os.makedirs(contexts_path, exist_ok=True)
 
         # write suite data
         data = self.to_dict()
@@ -474,7 +460,7 @@ class Suite(object):
 
         # create alias wrappers
         tools_path = os.path.join(path, "bin")
-        os.makedirs(tools_path)
+        os.makedirs(tools_path, exist_ok=True)
         if verbose:
             print("creating alias wrappers in %r..." % tools_path)
 
