@@ -20,8 +20,8 @@ from rez.tests.util import TestBase, TempdirMixin
 from rez.utils.formatting import PackageRequest
 from rez.utils.sourcecode import SourceCode
 import unittest
-from rez.vendor.version.version import Version
-from rez.vendor.version.util import VersionError
+from rez.version import Version
+from rez.version import VersionError
 from rez.utils.filesystem import canonical_path
 import shutil
 import os.path
@@ -57,7 +57,10 @@ ALL_PACKAGES = set([
     'late_binding-1.0',
     'timestamped-1.0.5', 'timestamped-1.0.6', 'timestamped-1.1.0', 'timestamped-1.1.1',
     'timestamped-1.2.0', 'timestamped-2.0.0', 'timestamped-2.1.0', 'timestamped-2.1.5',
-    'multi-1.0', 'multi-1.1', 'multi-1.2', 'multi-2.0'
+    'multi-1.0', 'multi-1.1', 'multi-1.2', 'multi-2.0',
+    'missing_variant_requires-1',
+    'test_weakly_reference_requires-2.0',
+    'test_weakly_reference_variant-2.0',
 ])
 
 
@@ -344,8 +347,7 @@ class TestPackages(TestBase, TempdirMixin):
     def test_variant_install(self):
         """test variant installation."""
         repo_path = os.path.join(self.root, "packages")
-        if not os.path.exists(repo_path):
-            os.makedirs(repo_path)
+        os.makedirs(repo_path, exist_ok=True)
 
         def _data(obj):
             d = obj.validated_data()
