@@ -5,16 +5,15 @@
 """
 test shell invocation
 """
-from __future__ import print_function
-
 from rez.system import system
 from rez.shells import create_shell, get_shell_types, get_shell_class
 from rez.resolved_context import ResolvedContext
 from rez.rex import literal, expandable
 from rez.plugin_managers import plugin_manager
 from rez.utils.execution import ExecutableScriptMode, _get_python_script_files
-from rez.tests.util import TestBase, TempdirMixin, per_available_shell, \
-    install_dependent
+from rez.utils.platform_ import platform_
+from rez.tests.util import TestBase, TempdirMixin, get_available_shells, \
+    per_available_shell, install_dependent
 from rez.bind import hello_world
 from rez.config import config
 import unittest
@@ -70,7 +69,10 @@ class TestShells(TestBase, TempdirMixin):
         shells = set(x for x in shells if x)
 
         if not shells:
-            self.skipTest("Not ensuring presence of shells from explicit list")
+            self.skipTest(
+                "Not ensuring presence of shells from explicit list because "
+                "$_REZ_ENSURE_TEST_SHELLS is either empty or not defined"
+            )
             return
 
         # check for missing shells
@@ -172,6 +174,71 @@ class TestShells(TestBase, TempdirMixin):
                                 stdout=subprocess.PIPE, text=True)
             self.assertEqual(_stdout(p), "Hello Rez World!")
 
+    @per_available_shell()
+    def test_per_available_shell_decorator(self, shell):
+        """
+        Test that the "per_available_shell" decorator correctly sets the default shell
+        and that ResolvedContext.execute_shell will use the default shell as expected.
+        """
+        # Based on:
+        # * https://stackoverflow.com/a/3327022
+        # * https://stackoverflow.com/a/61469226
+        # * https://stackoverflow.com/a/27776822
+        data = {
+            "bash": {
+                "command": "echo $BASH",
+                "assert": lambda x: self.assertEqual(os.path.basename(x), "bash"),
+            },
+            "gitbash": {
+                "command": "uname -s",
+                "assert": lambda x: self.assertRegex(x, r"^(MINGW|CYGWIN|MSYS).*$")
+            },
+            "csh": {
+                "command": "echo $shell",
+                # csh should usually resolve to csh, but on macOS, it will resolve to tcsh,
+                # at least on GitHub Actions Hosted runners.
+                "assert": lambda x: self.assertEqual(
+                    os.path.basename(x), "csh" if system.platform != "osx" else "tcsh"
+                ),
+            },
+            "tcsh": {
+                "command": "echo $shell",
+                "assert": lambda x: self.assertEqual(os.path.basename(x), "tcsh"),
+            },
+            "sh": {
+                # This is a hack. $0 doesn't work when run through execute_shell,
+                # but will work when running "rez-env --shell sh -c 'echo $0'"
+                # Output result to /dev/null because we don't want the content to affect the test,
+                # we just want to test is the variable exists.
+                "command": "set -o nounset; echo $REZ_STORED_PROMPT_SH > /dev/null",
+                "assert": lambda x: self.assertEqual(x, ""),
+            },
+            "zsh": {
+                "command": "echo $ZSH_NAME",
+                "assert": lambda x: self.assertEqual(os.path.basename(x), "zsh"),
+            },
+            "powershell": {
+                "command": "echo $PSVersionTable.PSEdition",
+                "assert": lambda x: self.assertEqual(x, "Desktop"),
+            },
+            "pwsh": {
+                "command": "echo $PSVersionTable.PSEdition",
+                "assert": lambda x: self.assertEqual(x, "Core"),
+            },
+            "cmd": {
+                "command": "dir 2>&1 *`|echo CMD",
+                "assert": lambda x: self.assertEqual(x, "CMD"),
+            },
+        }
+
+        if shell not in data:
+            self.fail("Please add support for {0!r} in the test".format(shell))
+
+        r = self._create_context([])
+        p = r.execute_shell(command=data[shell]["command"],
+                            stdout=subprocess.PIPE, text=True)
+        data[shell]["assert"](_stdout(p).strip())
+
     @per_available_shell()
     def test_command_returncode(self, shell):
         sh = create_shell(shell)
@@ -186,6 +253,39 @@ class TestShells(TestBase, TempdirMixin):
                     p.wait()
                 self.assertEqual(p.returncode, 66)
 
+    @unittest.skipIf(platform_.name != "windows", "GUI entrypoint test is only relevant on Windows")
+    @unittest.skipIf("pwsh" not in get_available_shells(), "PowerShell unavailable or disabled")
+    def test_pwsh_lastexitcode_gui(self):
+        """This validates some semi-unintuitive behavior on Windows, where GUI applications
+        will "return" immediately without any exit status when launched from a shell.
+        """
+        sh = create_shell("pwsh")
+        _, _, _, command = sh.startup_capabilities(command=True)
+
+        if command:
+            def actions_callback(ex):
+                """Action callback to enable PowerShell's "strict" mode."""
+                ex.command("Set-StrictMode -version Latest")
+
+            r = self._create_context(["hello_world"])
+            command = "hello_world -q -r 66"
+            commands = (command, command.split())
+            for cmd in commands:
+                with r.execute_shell(shell="pwsh", command=cmd, actions_callback=actions_callback,
+                                     stdout=subprocess.PIPE) as p:
+                    p.wait()
+                self.assertEqual(p.returncode, 66)
+
+            command = "hello_world_gui -q -r 49"
+            commands = (command, command.split())
+            for cmd in commands:
+                with r.execute_shell(shell="pwsh", command=cmd, actions_callback=actions_callback,
+                                     stdout=subprocess.PIPE) as p:
+                    p.wait()
+                # The GUI application should return control to the shell immediately, and that
+                # should bubble up through the rez shell as a 0 exit status.
+                self.assertEqual(p.returncode, 0)
+
     @per_available_shell()
     def test_norc(self, shell):
         sh = create_shell(shell)
@@ -419,6 +519,7 @@ class TestShells(TestBase, TempdirMixin):
             from rez.shells import create_shell
             sh = create_shell()
 
+            env.FOO.unset()
             env.FOO.append("hey")
             info(sh.get_key_token("FOO"))
             env.FOO.append(literal("$DAVE"))
@@ -434,6 +535,26 @@ class TestShells(TestBase, TempdirMixin):
 
         _execute_code(_rex_appending, expected_output)
 
+        def _rex_prepending():
+            from rez.shells import create_shell
+            sh = create_shell()
+
+            env.FOO.unset()
+            env.FOO.prepend("hey")
+            info(sh.get_key_token("FOO"))
+            env.FOO.prepend(literal("$DAVE"))
+            info(sh.get_key_token("FOO"))
+            env.FOO.prepend("Dave's not here man")
+            info(sh.get_key_token("FOO"))
+
+        expected_output = [
+            "hey",
+            sh.pathsep.join(["$DAVE", "hey"]),
+            sh.pathsep.join(["Dave's not here man", "$DAVE", "hey"])
+        ]
+
+        _execute_code(_rex_prepending, expected_output)
+
     @per_available_shell()
     def test_rex_code_alias(self, shell):
         """Ensure PATH changes do not influence the alias command.
@@ -504,6 +625,34 @@ class TestShells(TestBase, TempdirMixin):
         out, _ = p.communicate()
         self.assertEqual(0, p.returncode)
 
+    @per_available_shell()
+    def test_alias_return_code(self, shell):
+        """Ensure return codes are correct while using aliases."""
+        config.override("default_shell", shell)
+
+        def _make_alias(ex):
+            ex.alias('my_alias', 'hello_world -r 1')
+
+        r = self._create_context(["hello_world"])
+        p = r.execute_shell(command='my_alias',
+                            actions_callback=_make_alias,
+                            stdout=subprocess.PIPE)
+
+        out, _ = p.communicate()
+        self.assertEqual(1, p.returncode)
+
+    @per_available_shell()
+    def test_find_executable_config_override(self, shell):
+        """Test the shell plugin returns correct exec override from settings."""
+        config.override("default_shell", shell)
+        override_attr = "plugins.shell.{}.executable_fullpath".format(shell)
+        cls = type(create_shell(shell))
+        with tempfile.TemporaryDirectory() as td:
+            exe_path = os.path.join(td, cls.executable_name())
+            with open(exe_path, 'w'):
+                config.override(override_attr, exe_path)
+                assert cls.find_executable(cls.executable_name()) == exe_path
+
 
 if __name__ == '__main__':
     unittest.main()
