@@ -1,24 +1,12 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 test dependency resolving algorithm
 """
-from __future__ import print_function
-
-from rez.vendor.version.requirement import Requirement
+import rez.exceptions
+from rez.version import Requirement
 from rez.solver import Solver, Cycle, SolverStatus
 from rez.config import config
 import unittest
@@ -225,6 +213,7 @@ class TestSolver(TestBase):
 
     def test_08(self):
         """Cyclic failures."""
+
         def _test(*pkgs):
             s = self._fail(*pkgs)
             self.assertTrue(isinstance(s.failure_reason(), Cycle))
@@ -259,6 +248,31 @@ class TestSolver(TestBase):
                      "test_variant_split_mid2-2.0[0]",
                      "test_variant_split_start-1.0[1]"])
 
+    def test_12_missing_variant_requires(self):
+        config.override("error_on_missing_variant_requires", True)
+        with self.assertRaises(rez.exceptions.PackageFamilyNotFoundError):
+            self._solve(["missing_variant_requires"], [])
+
+        config.override("error_on_missing_variant_requires", False)
+        self._solve(["missing_variant_requires"], ["nada[]", "missing_variant_requires-1[1]"])
+
+    def test_13_resolve_weakly_reference_requires(self):
+        """Test resolving a package with a weakly referenced requirement."""
+        self._solve(["test_weakly_reference_requires", "test_variant_split_mid2-2"],
+                    ['test_weakly_reference_requires-2.0[]',
+                     'test_variant_split_end-3.0[0]',
+                     'test_variant_split_mid2-2.0[1]'])
+
+    def test_14_resolve_weakly_reference_variant(self):
+        """Test resolving a package with a weakly referenced variant."""
+        self._solve(["test_weakly_reference_variant-2.0", "test_variant_split_mid2-2", "pyfoo"],
+                    ['test_variant_split_end-1.0[1]',
+                     'test_variant_split_mid1-1.0[1]',
+                     'test_weakly_reference_variant-2.0[0]',
+                     'test_variant_split_mid2-2.0[0]',
+                     'python-2.6.8[]',
+                     'pyfoo-3.1.0[]'])
+
 
 if __name__ == '__main__':
     unittest.main()
