@@ -1,30 +1,20 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 Misc useful stuff.
 TODO: Move this into rez.utils.?
 """
-import collections
+import collections.abc
 import atexit
 import os
 import os.path
 import re
+import inspect
+
 from rez.exceptions import RezError
 from rez.vendor.progress.bar import Bar
-from rez.vendor.six import six
 
 
 class ProgressBar(Bar):
@@ -77,7 +67,7 @@ def shlex_join(value, unsafe_regex=None, replacements=None,
             return s
 
         for from_, to_ in (replacements or []):
-            if isinstance(from_, six.string_types):
+            if isinstance(from_, str):
                 s = s.replace(from_, to_)
             else:
                 s = from_.sub(to_, s)  # assume from_ is re.compile
@@ -164,13 +154,37 @@ def _atexit():
 
 def is_non_string_iterable(arg):
     """Python 2 and 3 compatible non-string iterable identifier"""
-
-    if six.PY2:
-        iterable_class = collections.Iterable
-    else:
-        iterable_class = collections.abc.Iterable
-
     return (
-        isinstance(arg, iterable_class)
-        and not isinstance(arg, six.string_types)
+        isinstance(arg, collections.abc.Iterable)
+        and not isinstance(arg, str)
     )
+
+
+def get_function_arg_names(func):
+    """Get names of a function's args.
+
+    Gives full list of positional and keyword-only args.
+    """
+    spec = inspect.getfullargspec(func)
+    return spec.args + spec.kwonlyargs
+
+
+def load_module_from_file(name, filepath):
+    """Load a python module from a sourcefile.
+
+    Args:
+        name (str): Module name.
+        filepath (str): Python sourcefile.
+
+    Returns:
+        `module`: Loaded module.
+    """
+    # The below code will import the module _without_ adding it to
+    # sys.modules. We want this otherwise we can't import multiple
+    # versions of the same module
+    # See: https://github.com/AcademySoftwareFoundation/rez/issues/1483
+    import importlib.util
+    spec = importlib.util.spec_from_file_location(name, filepath)
+    module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(module)
+    return module
