@@ -1,27 +1,17 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 import atexit
+import json
 import socket
 import time
 import threading
 import logging
+import urllib.parse
+import queue
 
-from rez.utils import json
 from rez.utils.logging_ import print_error
-from rez.vendor.six.six.moves import queue, urllib
 from rez.vendor.pika.adapters.blocking_connection import BlockingConnection
 from rez.vendor.pika.connection import ConnectionParameters
 from rez.vendor.pika.credentials import PlainCredentials
