@@ -5,8 +5,6 @@
 """
 Filesystem-related utilities.
 """
-from __future__ import print_function
-
 from threading import Lock
 from tempfile import mkdtemp
 from contextlib import contextmanager
@@ -24,9 +22,9 @@ import stat
 import platform
 import uuid
 
-from rez.vendor.six import six
 from rez.utils.platform_ import platform_
-
+from rez.util import which
+from rez.utils.execution import Popen
 
 is_windows = platform.system() == "Windows"
 
@@ -175,19 +173,6 @@ def safe_listdir(path):
         raise
 
 
-def safe_makedirs(path):
-    """Safe makedirs.
-
-    Works in a multithreaded scenario.
-    """
-    if not os.path.exists(path):
-        try:
-            os.makedirs(path)
-        except OSError:
-            if not os.path.exists(path):
-                raise
-
-
 def safe_remove(path):
     """Safely remove the given file or directory.
 
@@ -216,8 +201,6 @@ def forceful_rmtree(path):
         * path length over 259 char (on Windows)
         * unicode path
     """
-    if six.PY2:
-        path = unicode(path)
 
     def _on_error(func, path, exc_info):
         try:
@@ -287,7 +270,7 @@ def replace_file_or_dir(dest, source):
 
     if not os.path.exists(dest):
         try:
-            os.rename(source, dest)
+            rename(source, dest)
             return
         except:
             if not os.path.exists(dest):
@@ -300,15 +283,14 @@ def replace_file_or_dir(dest, source):
         pass
 
     with make_tmp_name(dest) as tmp_dest:
-        os.rename(dest, tmp_dest)
-        os.rename(source, dest)
+        rename(dest, tmp_dest)
+        rename(source, dest)
 
 
 def additive_copytree(src, dst, symlinks=False, ignore=None):
     """Version of `copytree` that merges into an existing directory.
     """
-    if not os.path.exists(dst):
-        os.makedirs(dst)
+    os.makedirs(dst, exist_ok=True)
 
     for item in os.listdir(src):
         s = os.path.join(src, item)
@@ -441,8 +423,7 @@ def copytree(src, dst, symlinks=False, ignore=None, hardlinks=False):
     else:
         copy = shutil.copy2
 
-    if not os.path.isdir(dst):
-        os.makedirs(dst)
+    os.makedirs(dst, exist_ok=True)
 
     errors = []
     for name in names:
@@ -507,14 +488,14 @@ def to_posixpath(path):
 
 
 def canonical_path(path, platform=None):
-    """ Resolves symlinks, and formats filepath.
+    r""" Resolves symlinks, and formats filepath.
 
     Resolves symlinks, lowercases if filesystem is case-insensitive,
     formats filepath using slashes appropriate for platform.
 
     Args:
         path (str): Filepath being formatted
-        platform (rez.utils.platform_.Platform): Indicates platform path is being
+        platform (rez.utils.platform\_.Platform): Indicates platform path is being
             formatted for. Defaults to current platform.
 
     Returns:
@@ -542,43 +523,42 @@ def encode_filesystem_name(input_str):
 
     The rules for the encoding are:
 
-    1) Any lowercase letter, digit, period, or dash (a-z, 0-9, ., or -) is
+    1. Any lowercase letter, digit, period, or dash (a-z, 0-9, ., or -) is
     encoded as-is.
 
-    2) Any underscore is encoded as a double-underscore ("__")
+    2. Any underscore is encoded as a double-underscore (``__``)
 
-    3) Any uppercase ascii letter (A-Z) is encoded as an underscore followed
+    3. Any uppercase ascii letter (A-Z) is encoded as an underscore followed
     by the corresponding lowercase letter (ie, "A" => "_a")
 
-    4) All other characters are encoded using their UTF-8 encoded unicode
-    representation, in the following format: "_NHH..., where:
-        a) N represents the number of bytes needed for the UTF-8 encoding,
-        except with N=0 for one-byte representation (the exception for N=1
-        is made both because it means that for "standard" ascii characters
-        in the range 0-127, their encoding will be _0xx, where xx is their
-        ascii hex code; and because it mirrors the ways UTF-8 encoding
-        itself works, where the number of bytes needed for the character can
-        be determined by counting the number of leading "1"s in the binary
-        representation of the character, except that if it is a 1-byte
-        sequence, there are 0 leading 1's).
-        b) HH represents the bytes of the corresponding UTF-8 encoding, in
-        hexadecimal (using lower-case letters)
+    4. All other characters are encoded using their UTF-8 encoded unicode
+       representation, in the following format: ``_NHH...``, where:
 
-        As an example, the character "*", whose (hex) UTF-8 representation
-        of 2A, would be encoded as "_02a", while the "euro" symbol, which
-        has a UTF-8 representation of E2 82 AC, would be encoded as
-        "_3e282ac".  (Note that, strictly speaking, the "N" part of the
-        encoding is redundant information, since it is essentially encoded
-        in the UTF-8 representation itself, but it makes the resulting
-        string more human-readable, and easier to decode).
+       * N represents the number of bytes needed for the UTF-8 encoding,
+         except with N=0 for one-byte representation (the exception for N=1
+         is made both because it means that for "standard" ascii characters
+         in the range 0-127, their encoding will be _0xx, where xx is their
+         ascii hex code; and because it mirrors the ways UTF-8 encoding
+         itself works, where the number of bytes needed for the character can
+         be determined by counting the number of leading "1"s in the binary
+         representation of the character, except that if it is a 1-byte
+         sequence, there are 0 leading 1's).
+       * HH represents the bytes of the corresponding UTF-8 encoding, in
+         hexadecimal (using lower-case letters)
 
-    As an example, the string "Foo_Bar (fun).txt" would get encoded as:
-        _foo___bar_020_028fun_029.txt
+         As an example, the character ``*``, whose (hex) UTF-8 representation
+         of 2A, would be encoded as "_02a", while the "euro" symbol, which
+         has a UTF-8 representation of E2 82 AC, would be encoded as
+         "_3e282ac".  (Note that, strictly speaking, the "N" part of the
+         encoding is redundant information, since it is essentially encoded
+         in the UTF-8 representation itself, but it makes the resulting
+         string more human-readable, and easier to decode).
+
+    As an example, the string "Foo_Bar (fun).txt" would get encoded as ``_foo___bar_020_028fun_029.txt``.
     """
-    if isinstance(input_str, six.string_types):
-        input_str = unicode(input_str)
-    elif not isinstance(input_str, unicode):
-        raise TypeError("input_str must be a %s" % six.string_types[0].__name__)
+    # TODO: Test this
+    if isinstance(input_str, str):
+        input_str = input_str.encode(encoding="utf-8")
 
     as_is = u'abcdefghijklmnopqrstuvwxyz0123456789.-'
     uppercase = u'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
@@ -697,3 +677,55 @@ def windows_long_path(dos_path):
         path = "\\\\?\\" + path
 
     return path
+
+
+def rename(src, dst):
+    """Utility function to rename a file or folder src to dst with retrying.
+
+    This function uses the built-in `os.rename()` function and falls back to `robocopy` tool
+    if `os.rename` raises a `PermissionError` exception.
+
+    Args:
+        src (str): The original name (path) of the file or folder.
+        dst (str): The new name (path) for the file or folder.
+
+    Raises:
+        OSError: If renaming fails after all attempts.
+
+    """
+    # Inspired by https://github.com/conan-io/conan/blob/2.1.0/conan/tools/files/files.py#L207
+    try:
+        os.rename(src, dst)
+    except PermissionError as err:
+        if is_windows and which("robocopy") and os.path.isdir(src):
+            # https://learn.microsoft.com/en-us/windows-server/administration/windows-commands/robocopy
+            args = [
+                "robocopy",
+                # /move Moves files and directories, and deletes them from the source after they are copied.
+                "/move",
+                # /e Copies subdirectories. Note that this option includes empty directories.
+                "/e",
+                # /ndl Specifies that directory names are not to be logged.
+                "/ndl",
+                # /nfl Specifies that file names are not to be logged.
+                "/nfl",
+                # /njs Specifies that there's no job summary.
+                "/njs",
+                # /njh Specifies that there's no job header.
+                "/njh",
+                # /np Specifies that the progress of the copying operation
+                # (the number of files or directories copied so far) won't be displayed.
+                "/np",
+                # /ns Specifies that file sizes aren't to be logged.
+                "/ns",
+                # /nc Specifies that file classes aren't to be logged.
+                "/nc",
+                src,
+                dst,
+            ]
+            process = Popen(args)
+            process.communicate()
+            if process.returncode > 7:  # https://ss64.com/nt/robocopy-exit.html
+                raise OSError("Rename {} to {} failed.".format(src, dst))
+        else:
+            raise err
