@@ -1,19 +1,7 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
 from contextlib import contextmanager
 import logging
 import time
@@ -74,11 +62,9 @@ class _Printer(object):
                 msg = msg % nargs
             self.printer_function(msg)
 
-    def __nonzero__(self):
+    def __bool__(self):
         return bool(self.printer_function)
 
-    __bool__ = __nonzero__  # py3 compat
-
 
 @contextmanager
 def log_duration(printer, msg):
@@ -96,7 +82,7 @@ def view_file_logs(globbed_path, loglevel_index=None):
     Prints to stdout.
 
     Args:
-        globbed_path (str): Logfiles, eg '/foo/logs/*.log'
+        globbed_path (str): Logfiles, eg ``/foo/logs/*.log``
         loglevel_index (int): Position on each log line where log level
             (INFO etc) is expected. This is used for colorisation only, and if
             None, no colors are applied.
