@@ -5,10 +5,8 @@
 """
 Functions for converting python distributions to rez packages.
 """
-from __future__ import print_function
-
 from rez.exceptions import RezSystemError
-import pkg_resources
+import importlib.metadata as importlib_metadata
 import shutil
 import sys
 import os
@@ -18,8 +16,7 @@ import textwrap
 
 def _mkdirs(*dirs):
     path = os.path.join(*dirs)
-    if not os.path.exists(path):
-        os.makedirs(path)
+    os.makedirs(path, exist_ok=True)
     return path
 
 
@@ -94,7 +91,7 @@ def get_dist_dependencies(name, recurse=True):
     @returns A set of package names.
     @note The first entry in the list is always the top-level package itself.
     """
-    dist = pkg_resources.get_distribution(name)
+    dist = importlib_metadata.Distribution.from_name(name)
     pkg_name = convert_name(dist.project_name)
 
     reqs = set()
@@ -104,7 +101,7 @@ def get_dist_dependencies(name, recurse=True):
     while working:
         deps = set()
         for distname in working:
-            dist = pkg_resources.get_distribution(distname)
+            dist = importlib_metadata.Distribution.from_name(distname)
             pkg_name = convert_name(dist.project_name)
             reqs.add(pkg_name)
 
@@ -134,6 +131,7 @@ def convert_dist(name, dest_path, make_variant=True, ignore_dirs=None,
         ignore_dirs (bool): List of directory names to not copy from the dist.
         python_requirement (str): How the package should depend on python.
             One of:
+
             - "major": depend on python-X
             - "major_minor": depend on python-X.X
             - any other value: this string is used as the literal version
@@ -142,7 +140,7 @@ def convert_dist(name, dest_path, make_variant=True, ignore_dirs=None,
     Returns:
         Install path of the new Rez package.
     """
-    dist = pkg_resources.get_distribution(name)
+    dist = importlib_metadata.distribution(name)
     pkg_name = convert_name(dist.project_name)
     pkg_version = convert_version(dist.version)
 
