@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
@@ -44,16 +33,16 @@ data load is avoided.
 
 See the 'pets' unit test in tests/test_resources.py for a complete example.
 """
+from functools import lru_cache
+
 from rez.utils.data_utils import cached_property, AttributeForwardMeta, \
     LazyAttributeMeta
 from rez.config import config
 from rez.exceptions import ResourceError
-from rez.backport.lru_cache import lru_cache
 from rez.utils.logging_ import print_debug
-from rez.vendor.six import six
 
 
-class Resource(six.with_metaclass(LazyAttributeMeta, object)):
+class Resource(object, metaclass=LazyAttributeMeta):
     """Abstract base class for a data resource.
 
     A resource is an object uniquely identified by a 'key' (the resource type),
@@ -78,16 +67,14 @@ class Resource(six.with_metaclass(LazyAttributeMeta, object)):
     Note:
         You can access the entire validated resource data dict using the
         `validated_data` function, and test full validation using `validate_data`.
-
-    Attributes:
-        key (str): Unique identifier of the resource type.
-        schema (Schema): Schema for the resource data. Must validate a dict.
-            Can be None, in which case the resource does not load any data.
-        schema_error (Exception): The exception type to raise on key
-            validation failure.
     """
+    #: Unique identifier of the resource type.
     key = None
+    #: Schema for the resource data.
+    #: Must validate a dict. Can be None, in which case the resource does
+    #: not load any data.
     schema = None
+    #: The exception type to raise on key validation failure.
     schema_error = Exception
 
     @classmethod
@@ -247,7 +234,7 @@ class ResourcePool(object):
         return resource_class(resource_handle.variables)
 
 
-class ResourceWrapper(six.with_metaclass(AttributeForwardMeta, object)):
+class ResourceWrapper(object, metaclass=AttributeForwardMeta):
     """An object that wraps a resource instance.
 
     A resource wrapper is useful for two main reasons. First, we can wrap
