@@ -5,13 +5,9 @@
 """
 Utilities for working with dict-based schemas.
 """
-from rez.vendor.six import six
 from rez.vendor.schema.schema import Schema, Optional, Use, And
 
 
-basestring = six.string_types[0]
-
-
 # an alias which just so happens to be the same number of characters as
 # 'Optional' so that our schema are easier to read
 Required = Schema
@@ -23,10 +19,12 @@ def schema_keys(schema):
     Non-string keys are ignored.
 
     Returns:
-        Set of string keys of a schema which is in the form (eg):
+        set[str]: Set of string keys of a schema which is in the form (eg):
 
-            schema = Schema({Required("foo"): int,
-                             Optional("bah"): basestring})
+        .. code-block:: python
+
+           schema = Schema({Required("foo"): int,
+                            Optional("bah"): str})
     """
     def _get_leaf(value):
         if isinstance(value, Schema):
@@ -39,7 +37,7 @@ def schema_keys(schema):
 
     for key in dict_.keys():
         key_ = _get_leaf(key)
-        if isinstance(key_, basestring):
+        if isinstance(key_, str):
             keys.add(key_)
 
     return keys
@@ -50,9 +48,9 @@ def dict_to_schema(schema_dict, required, allow_custom_keys=True, modifier=None)
 
     Args:
         required (bool): Whether to make schema keys optional or required.
-        allow_custom_keys (bool, optional): If True, creates a schema that
+        allow_custom_keys (typing.Optional[bool]): If True, creates a schema that
             allows custom items in dicts.
-        modifier (callable): Functor to apply to dict values - it is applied
+        modifier (typing.Optional[typing.Callable]): Functor to apply to dict values - it is applied
             via `Schema.Use`.
 
     Returns:
@@ -65,11 +63,11 @@ def dict_to_schema(schema_dict, required, allow_custom_keys=True, modifier=None)
         if isinstance(value, dict):
             d = {}
             for k, v in value.items():
-                if isinstance(k, basestring):
+                if isinstance(k, str):
                     k = Required(k) if required else Optional(k)
                 d[k] = _to(v)
             if allow_custom_keys:
-                d[Optional(basestring)] = modifier or object
+                d[Optional(str)] = modifier or object
             schema = Schema(d)
         elif modifier:
             schema = And(value, modifier)
@@ -87,7 +85,7 @@ def extensible_schema_dict(schema_dict):
     older rez versions, that may not support newer schema fields.
     """
     result = {
-        Optional(basestring): object
+        Optional(str): object
     }
 
     result.update(schema_dict)
