@@ -2,10 +2,8 @@
 # Copyright Contributors to the Rez Project
 
 
-from __future__ import print_function
-
 from rez.utils.formatting import StringFormatMixin, StringFormatType
-from rez.vendor.six.six.moves import UserDict
+from collections import UserDict
 import sys
 
 
@@ -56,7 +54,7 @@ class RecursiveAttribute(UserDict, StringFormatMixin):
         # to something. This stops code like "print(instance.notexist)" from
         # adding empty attributes
         attr_ = self._create_child_attribute(attr)
-        assert(isinstance(attr_, RecursiveAttribute))
+        assert isinstance(attr_, RecursiveAttribute)
         attr_.__dict__["pending"] = (attr, self)
         return attr_
 
@@ -219,8 +217,8 @@ class ScopeContext(object):
 
     def _scope_exit(self, name):
         scope = self.scope_stack.pop()
-        assert(self.scope_stack)
-        assert(name == scope.name)
+        assert self.scope_stack
+        assert name == scope.name
         data = {scope.name: scope.to_dict()}
         self.scope_stack[-1].update(data)
 
