@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 from Qt import QtWidgets
@@ -19,15 +8,11 @@ from rezgui.mixins.ContextViewMixin import ContextViewMixin
 from rezgui.models.ContextModel import ContextModel
 from rez.config import config
 from rez.vendor import yaml
-from rez.vendor.six import six
 from rez.vendor.yaml.error import YAMLError
 from rez.vendor.schema.schema import Schema, SchemaError, Or, And, Use
 from functools import partial
 
 
-basestring = six.string_types[0]
-
-
 class ContextSettingsWidget(QtWidgets.QWidget, ContextViewMixin):
 
     titles = {
@@ -38,8 +23,8 @@ class ContextSettingsWidget(QtWidgets.QWidget, ContextViewMixin):
     }
 
     schema_dict = {
-        "packages_path":        [basestring],
-        "implicit_packages":    [basestring],
+        "packages_path":        [str],
+        "implicit_packages":    [str],
         "package_filter":       Or(And(None, Use(lambda x: [])),
                                    And(dict, Use(lambda x: [x])),
                                    [dict]),
