@@ -1,23 +1,10 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 CMake-based build system
 """
-from __future__ import print_function
-
 from rez.build_system import BuildSystem
 from rez.build_process import BuildType
 from rez.resolved_context import ResolvedContext
@@ -28,7 +15,6 @@ from rez.utils.platform_ import platform_
 from rez.config import config
 from rez.utils.which import which
 from rez.vendor.schema.schema import Or
-from rez.vendor.six import six
 from rez.shells import create_shell
 import functools
 import os.path
@@ -36,9 +22,6 @@ import sys
 import os
 
 
-basestring = six.string_types[0]
-
-
 class RezCMakeError(BuildSystemError):
     pass
 
@@ -73,9 +56,9 @@ class CMakeBuildSystem(BuildSystem):
     schema_dict = {
         "build_target": Or(*build_targets),
         "build_system": Or(*list(build_systems.keys())),
-        "cmake_args": [basestring],
-        "cmake_binary": Or(None, basestring),
-        "make_binary": Or(None, basestring)
+        "cmake_args": [str],
+        "cmake_binary": Or(None, str),
+        "make_binary": Or(None, str)
     }
 
     @classmethod
@@ -143,7 +126,7 @@ class CMakeBuildSystem(BuildSystem):
 
         # assemble cmake command
         cmd = [found_exe]
-        # cmd.append("-d")  # see https://github.com/nerdvegas/rez/issues/1055
+        # cmd.append("-d")  # see #1055
         cmd.append(self.working_dir)
 
         cmd += (self.settings.cmake_args or [])
@@ -157,11 +140,6 @@ class CMakeBuildSystem(BuildSystem):
         cmd.append("-DREZ_BUILD_INSTALL=%d" % (1 if install else 0))
         cmd.extend(["-G", self.build_systems[self.cmake_build_system]])
 
-        if config.rez_1_cmake_variables and \
-                not config.disable_rez_1_compatibility and \
-                build_type == BuildType.central:
-            cmd.append("-DCENTRAL=1")
-
         # execute cmake within the build env
         _pr("Executing: %s" % ' '.join(cmd))
         if not os.path.abspath(build_path):
