@@ -1,33 +1,16 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
 Publishes a message to the broker.
 """
-from __future__ import print_function
-
 from rez.release_hook import ReleaseHook
 from rez.utils.logging_ import print_error, print_debug
 from rez.utils.amqp import publish_message
-from rez.vendor.six import six
 from rez.config import config
 
 
-basestring = six.string_types[0]
-
-
 class AmqpReleaseHook(ReleaseHook):
     """
     Publishes a message to the broker.
@@ -49,12 +32,12 @@ class AmqpReleaseHook(ReleaseHook):
         }
     """
     schema_dict = {
-        "host":                     basestring,
-        "userid":                   basestring,
-        "password":                 basestring,
+        "host":                     str,
+        "userid":                   str,
+        "password":                 str,
         "connect_timeout":          int,
-        "exchange_name":            basestring,
-        "exchange_routing_key":     basestring,
+        "exchange_name":            str,
+        "exchange_routing_key":     str,
         "message_delivery_mode":    int,
         "message_attributes":       dict}
 
