@@ -5,8 +5,6 @@
 """
 Git version control
 """
-from __future__ import print_function
-
 from rez.release_vcs import ReleaseVCS
 from rez.utils.logging_ import print_error, print_debug
 from rez.exceptions import ReleaseVCSError
@@ -61,7 +59,7 @@ class GitReleaseVCS(ReleaseVCS):
             try:
                 s2 = toks[-1]
                 adj, n = s2.split()
-                assert(adj in ("ahead", "behind"))
+                assert adj in ("ahead", "behind")
                 n = int(n)
                 return -n if adj == "behind" else n
             except Exception as e:
