@@ -5,10 +5,10 @@
 """
 CSH shell
 """
-import pipes
 import os.path
 import subprocess
 import re
+from shlex import quote
 
 from rez.config import config
 from rez.util import shlex_join
@@ -46,7 +46,7 @@ class CSH(UnixShell):
               % (cls.name(), cls.command_arg)
         p = Popen(cmd, stdout=subprocess.PIPE,
                   stderr=subprocess.PIPE, shell=True, text=True)
-        out_, err_ = p.communicate()
+        out_, _ = p.communicate()
         if p.returncode:
             paths = []
         else:
@@ -105,7 +105,7 @@ class CSH(UnixShell):
 
         for is_literal, txt in value.strings:
             if is_literal:
-                txt = pipes.quote(txt)
+                txt = quote(txt)
                 if not txt.startswith("'"):
                     txt = "'%s'" % txt
             else:
