@@ -9,8 +9,8 @@ from rez.utils.platform_ import platform_
 from rezplugins.shell.csh import CSH
 from rez import module_root_path
 from rez.rex import EscapedString
+from shlex import quote
 import os.path
-import pipes
 
 
 class TCSH(CSH):
@@ -19,17 +19,20 @@ class TCSH(CSH):
     def name(cls):
         return 'tcsh'
 
-    def escape_string(self, value):
+    def escape_string(self, value, is_path=False):
         value = EscapedString.promote(value)
         value = value.expanduser()
         result = ''
 
         for is_literal, txt in value.strings:
             if is_literal:
-                txt = pipes.quote(txt)
+                txt = quote(txt)
                 if not txt.startswith("'"):
                     txt = "'%s'" % txt
             else:
+                if is_path:
+                    txt = self.normalize_paths(txt)
+
                 txt = txt.replace('"', '"\\""')
                 txt = txt.replace('!', '\\!')
                 txt = '"%s"' % txt
